Class: Google::Apis::OndemandscanningV1beta1::AnalyzePackagesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

AnalyzePackagesResponse contains the information necessary to find results for the given scan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AnalyzePackagesResponse

Returns a new instance of AnalyzePackagesResponse.



189
190
191
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scanString

The name of the scan resource created by this successful scan. Corresponds to the JSON property scan

Returns:

  • (String)


187
188
189
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 187

def scan
  @scan
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



194
195
196
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 194

def update!(**args)
  @scan = args[:scan] if args.key?(:scan)
end