Class: Google::Apis::OndemandscanningV1beta1::AnalyzePackagesResponseV1

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

AnalyzePackagesResponse contains the information necessary to find results for the given scan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AnalyzePackagesResponseV1

Returns a new instance of AnalyzePackagesResponseV1.



203
204
205
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scanString

The name of the scan resource created by this successful scan. Corresponds to the JSON property scan

Returns:

  • (String)


201
202
203
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 201

def scan
  @scan
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



208
209
210
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 208

def update!(**args)
  @scan = args[:scan] if args.key?(:scan)
end