Class: Google::Apis::OndemandscanningV1beta1::BaseImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BaseImage

Returns a new instance of BaseImage.



327
328
329
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


310
311
312
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 310

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 315

def name
  @name
end

#registryString

The registry in which the base image is from. Corresponds to the JSON property registry

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 320

def registry
  @registry
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


325
326
327
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 325

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



332
333
334
335
336
337
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 332

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @registry = args[:registry] if args.key?(:registry)
  @repository = args[:repository] if args.key?(:repository)
end