Class: Google::Apis::OndemandscanningV1beta1::BuildOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Details of a build occurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuildOccurrence

Returns a new instance of BuildOccurrence.



444
445
446
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#in_toto_slsa_provenance_v1Google::Apis::OndemandscanningV1beta1::InTotoSlsaProvenanceV1

In-Toto Slsa Provenance V1 represents a slsa provenance meeting the slsa spec, wrapped in an in-toto statement. This allows for direct jsonification of a to- spec in-toto slsa statement with a to-spec slsa provenance. Corresponds to the JSON property inTotoSlsaProvenanceV1



411
412
413
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 411

def in_toto_slsa_provenance_v1
  @in_toto_slsa_provenance_v1
end

#intoto_provenanceGoogle::Apis::OndemandscanningV1beta1::InTotoProvenance

Deprecated. See InTotoStatement for the replacement. In-toto Provenance representation as defined in spec. Corresponds to the JSON property intotoProvenance



417
418
419
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 417

def intoto_provenance
  @intoto_provenance
end

#intoto_statementGoogle::Apis::OndemandscanningV1beta1::InTotoStatement

Spec defined at https://github.com/in-toto/attestation/tree/main/spec# statement The serialized InTotoStatement will be stored as Envelope.payload. Envelope.payloadType is always "application/vnd.in-toto+json". Corresponds to the JSON property intotoStatement



424
425
426
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 424

def intoto_statement
  @intoto_statement
end

#provenanceGoogle::Apis::OndemandscanningV1beta1::BuildProvenance

Provenance of a build. Contains all information needed to verify the full details about the build from source to completion. Corresponds to the JSON property provenance



430
431
432
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 430

def provenance
  @provenance
end

#provenance_bytesString

Serialized JSON representation of the provenance, used in generating the build signature in the corresponding build note. After verifying the signature, provenance_bytes can be unmarshalled and compared to the provenance to confirm that it is unchanged. A base64-encoded string representation of the provenance bytes is used for the signature in order to interoperate with openssl which expects this format for signature verification. The serialized form is captured both to avoid ambiguity in how the provenance is marshalled to json as well to prevent incompatibilities with future changes. Corresponds to the JSON property provenanceBytes

Returns:

  • (String)


442
443
444
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 442

def provenance_bytes
  @provenance_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



449
450
451
452
453
454
455
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 449

def update!(**args)
  @in_toto_slsa_provenance_v1 = args[:in_toto_slsa_provenance_v1] if args.key?(:in_toto_slsa_provenance_v1)
  @intoto_provenance = args[:intoto_provenance] if args.key?(:intoto_provenance)
  @intoto_statement = args[:intoto_statement] if args.key?(:intoto_statement)
  @provenance = args[:provenance] if args.key?(:provenance)
  @provenance_bytes = args[:provenance_bytes] if args.key?(:provenance_bytes)
end