Class: Google::Apis::OndemandscanningV1beta1::ComplianceOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::ComplianceOccurrence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.
Instance Attribute Summary collapse
-
#non_compliance_reason ⇒ String
Corresponds to the JSON property
nonComplianceReason. -
#non_compliant_files ⇒ Array<Google::Apis::OndemandscanningV1beta1::NonCompliantFile>
Corresponds to the JSON property
nonCompliantFiles. -
#version ⇒ Google::Apis::OndemandscanningV1beta1::ComplianceVersion
Describes the CIS benchmark version that is applicable to a given OS and os version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComplianceOccurrence
constructor
A new instance of ComplianceOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComplianceOccurrence
Returns a new instance of ComplianceOccurrence.
848 849 850 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#non_compliance_reason ⇒ String
Corresponds to the JSON property nonComplianceReason
835 836 837 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 835 def non_compliance_reason @non_compliance_reason end |
#non_compliant_files ⇒ Array<Google::Apis::OndemandscanningV1beta1::NonCompliantFile>
Corresponds to the JSON property nonCompliantFiles
840 841 842 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 840 def non_compliant_files @non_compliant_files end |
#version ⇒ Google::Apis::OndemandscanningV1beta1::ComplianceVersion
Describes the CIS benchmark version that is applicable to a given OS and os
version.
Corresponds to the JSON property version
846 847 848 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 846 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
853 854 855 856 857 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 853 def update!(**args) @non_compliance_reason = args[:non_compliance_reason] if args.key?(:non_compliance_reason) @non_compliant_files = args[:non_compliant_files] if args.key?(:non_compliant_files) @version = args[:version] if args.key?(:version) end |