Class: Google::Apis::OndemandscanningV1beta1::ComplianceVersion
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::ComplianceVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Describes the CIS benchmark version that is applicable to a given OS and os version.
Instance Attribute Summary collapse
-
#benchmark_document ⇒ String
The name of the document that defines this benchmark, e.g.
-
#cpe_uri ⇒ String
The CPE URI (https://cpe.mitre.org/specification/) this benchmark is applicable to.
-
#version ⇒ String
The version of the benchmark.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComplianceVersion
constructor
A new instance of ComplianceVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComplianceVersion
Returns a new instance of ComplianceVersion.
961 962 963 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#benchmark_document ⇒ String
The name of the document that defines this benchmark, e.g. "CIS Container-
Optimized OS".
Corresponds to the JSON property benchmarkDocument
947 948 949 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 947 def benchmark_document @benchmark_document end |
#cpe_uri ⇒ String
The CPE URI (https://cpe.mitre.org/specification/) this benchmark is
applicable to.
Corresponds to the JSON property cpeUri
953 954 955 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 953 def cpe_uri @cpe_uri end |
#version ⇒ String
The version of the benchmark. This is set to the version of the OS-specific
CIS document the benchmark is defined in.
Corresponds to the JSON property version
959 960 961 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 959 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
966 967 968 969 970 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 966 def update!(**args) @benchmark_document = args[:benchmark_document] if args.key?(:benchmark_document) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @version = args[:version] if args.key?(:version) end |