Class: Google::Apis::OndemandscanningV1beta1::ExploitPredictionScoringSystem
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::ExploitPredictionScoringSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#percentile ⇒ Float
The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score Corresponds to the JSON property
percentile. -
#score ⇒ Float
The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days Corresponds to the JSON property
score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExploitPredictionScoringSystem
constructor
A new instance of ExploitPredictionScoringSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExploitPredictionScoringSystem
Returns a new instance of ExploitPredictionScoringSystem.
1152 1153 1154 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percentile ⇒ Float
The percentile of the current score, the proportion of all scored
vulnerabilities with the same or a lower EPSS score
Corresponds to the JSON property percentile
1144 1145 1146 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1144 def percentile @percentile end |
#score ⇒ Float
The EPSS score representing the probability [0-1] of exploitation in the wild
in the next 30 days
Corresponds to the JSON property score
1150 1151 1152 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1150 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1157 1158 1159 1160 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1157 def update!(**args) @percentile = args[:percentile] if args.key?(:percentile) @score = args[:score] if args.key?(:score) end |