Class: Google::Apis::OndemandscanningV1beta1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::FileHashes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
1294 1295 1296 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::OndemandscanningV1beta1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
1292 1293 1294 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1292 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1299 1300 1301 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1299 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |