Class: Google::Apis::OndemandscanningV1beta1::Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Finding provides details for a single finding within an AISkillAnalysisOccurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Finding

Returns a new instance of Finding.



1311
1312
1313
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Category of the finding. Corresponds to the JSON property category

Returns:

  • (String)


1279
1280
1281
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1279

def category
  @category
end

#descriptionString

Detailed description of the finding. Corresponds to the JSON property description

Returns:

  • (String)


1284
1285
1286
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1284

def description
  @description
end

#file_pathString

Path to the file where the finding was detected. Corresponds to the JSON property filePath

Returns:

  • (String)


1289
1290
1291
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1289

def file_path
  @file_path
end

#rule_idString

Unique identifier of the rule that produced this finding. Corresponds to the JSON property ruleId

Returns:

  • (String)


1294
1295
1296
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1294

def rule_id
  @rule_id
end

#severityString

Severity of the finding. Corresponds to the JSON property severity

Returns:

  • (String)


1299
1300
1301
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1299

def severity
  @severity
end

#snippetString

Code snippet relevant to the finding. Corresponds to the JSON property snippet

Returns:

  • (String)


1304
1305
1306
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1304

def snippet
  @snippet
end

#titleString

Title of the finding. Corresponds to the JSON property title

Returns:

  • (String)


1309
1310
1311
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1309

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1316
1317
1318
1319
1320
1321
1322
1323
1324
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1316

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @description = args[:description] if args.key?(:description)
  @file_path = args[:file_path] if args.key?(:file_path)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
  @severity = args[:severity] if args.key?(:severity)
  @snippet = args[:snippet] if args.key?(:snippet)
  @title = args[:title] if args.key?(:title)
end