Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1LayerDetails
constructor
A new instance of GrafeasV1LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1LayerDetails
Returns a new instance of GrafeasV1LayerDetails.
1606 1607 1608 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
1582 1583 1584 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1582 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
1588 1589 1590 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1588 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
1594 1595 1596 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1594 def command @command end |
#diff_id ⇒ String
The diff ID (typically a sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
1599 1600 1601 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1599 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
1604 1605 1606 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1604 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1611 1612 1613 1614 1615 1616 1617 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1611 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |