Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.



1689
1690
1691
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


1677
1678
1679
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1677

def digest
  @digest
end

#entry_pointString

Corresponds to the JSON property entryPoint

Returns:

  • (String)


1682
1683
1684
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1682

def entry_point
  @entry_point
end

#uriString

Corresponds to the JSON property uri

Returns:

  • (String)


1687
1688
1689
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1687

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1694
1695
1696
1697
1698
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1694

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @entry_point = args[:entry_point] if args.key?(:entry_point)
  @uri = args[:uri] if args.key?(:uri)
end