Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Identifies the event that kicked off the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation.



1541
1542
1543
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_sourceGoogle::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource

Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from. Corresponds to the JSON property configSource



1529
1530
1531
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1529

def config_source
  @config_source
end

#environmentHash<String,Object>

Corresponds to the JSON property environment

Returns:

  • (Hash<String,Object>)


1534
1535
1536
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1534

def environment
  @environment
end

#parametersHash<String,Object>

Corresponds to the JSON property parameters

Returns:

  • (Hash<String,Object>)


1539
1540
1541
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1539

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1546
1547
1548
1549
1550
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1546

def update!(**args)
  @config_source = args[:config_source] if args.key?(:config_source)
  @environment = args[:environment] if args.key?(:environment)
  @parameters = args[:parameters] if args.key?(:parameters)
end