Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial.



1754
1755
1756
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


1747
1748
1749
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1747

def digest
  @digest
end

#uriString

Corresponds to the JSON property uri

Returns:

  • (String)


1752
1753
1754
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1752

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1759
1760
1761
1762
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1759

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @uri = args[:uri] if args.key?(:uri)
end