Class: Google::Apis::OndemandscanningV1beta1::IngestionSource
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::IngestionSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Indicates where an extracted package originates from.
Instance Attribute Summary collapse
-
#attachment_uri ⇒ String
The attachment URI that this package was extracted from.
-
#resource_url ⇒ String
The resource URL of the resource that was scanned to find this package.
-
#source ⇒ String
Corresponds to the JSON property
source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestionSource
constructor
A new instance of IngestionSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestionSource
Returns a new instance of IngestionSource.
2053 2054 2055 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_uri ⇒ String
The attachment URI that this package was extracted from.
Corresponds to the JSON property attachmentUri
2041 2042 2043 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2041 def @attachment_uri end |
#resource_url ⇒ String
The resource URL of the resource that was scanned to find this package.
Corresponds to the JSON property resourceUrl
2046 2047 2048 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2046 def resource_url @resource_url end |
#source ⇒ String
Corresponds to the JSON property source
2051 2052 2053 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2051 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2058 2059 2060 2061 2062 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2058 def update!(**args) @attachment_uri = args[:attachment_uri] if args.key?(:attachment_uri) @resource_url = args[:resource_url] if args.key?(:resource_url) @source = args[:source] if args.key?(:source) end |