Class: Google::Apis::OndemandscanningV1beta1::License

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

License information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ License

Returns a new instance of License.



2177
2178
2179
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentsString

Comments Corresponds to the JSON property comments

Returns:

  • (String)


2167
2168
2169
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2167

def comments
  @comments
end

#expressionString

Often a single license can be used to represent the licensing terms. Sometimes it is necessary to include a choice of one or more licenses or some combination of license identifiers. Examples: "LGPL-2.1-only OR MIT", "LGPL-2. 1-only AND MIT", "GPL-2.0-or-later WITH Bison-exception-2.2". Corresponds to the JSON property expression

Returns:

  • (String)


2175
2176
2177
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2175

def expression
  @expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2182
2183
2184
2185
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2182

def update!(**args)
  @comments = args[:comments] if args.key?(:comments)
  @expression = args[:expression] if args.key?(:expression)
end