Class: Google::Apis::OndemandscanningV1beta1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



2685
2686
2687
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advisory_publish_timeString

The time this advisory was published by the source. Corresponds to the JSON property advisoryPublishTime

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2556

def advisory_publish_time
  @advisory_publish_time
end

#ai_skill_analysisGoogle::Apis::OndemandscanningV1beta1::AiSkillAnalysisOccurrence

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



2561
2562
2563
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2561

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::OndemandscanningV1beta1::AttestationOccurrence

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for lookup (how to find this attestation if you already know the authority and artifact to be verified) and intent (for which authority this attestation was intended to sign. Corresponds to the JSON property attestation



2572
2573
2574
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2572

def attestation
  @attestation
end

#buildGoogle::Apis::OndemandscanningV1beta1::BuildOccurrence

Details of a build occurrence. Corresponds to the JSON property build



2577
2578
2579
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2577

def build
  @build
end

#complianceGoogle::Apis::OndemandscanningV1beta1::ComplianceOccurrence

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason. Corresponds to the JSON property compliance



2583
2584
2585
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2583

def compliance
  @compliance
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2588

def create_time
  @create_time
end

#deploymentGoogle::Apis::OndemandscanningV1beta1::DeploymentOccurrence

The period during which some deployable was active in a runtime. Corresponds to the JSON property deployment



2593
2594
2595
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2593

def deployment
  @deployment
end

#discoveryGoogle::Apis::OndemandscanningV1beta1::DiscoveryOccurrence

Provides information about the analysis status of a discovered resource. Corresponds to the JSON property discovery



2598
2599
2600
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2598

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::OndemandscanningV1beta1::DsseAttestationOccurrence

Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at the top level of the Occurrence. Corresponds to the JSON property dsseAttestation



2604
2605
2606
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2604

def dsse_attestation
  @dsse_attestation
end

#envelopeGoogle::Apis::OndemandscanningV1beta1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



2610
2611
2612
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2610

def envelope
  @envelope
end

#imageGoogle::Apis::OndemandscanningV1beta1::ImageOccurrence

Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM . Corresponds to the JSON property image



2616
2617
2618
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2616

def image
  @image
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


2622
2623
2624
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2622

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


2628
2629
2630
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2628

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


2635
2636
2637
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2635

def note_name
  @note_name
end

#packageGoogle::Apis::OndemandscanningV1beta1::PackageOccurrence

Details on how a particular software package was installed on a system. Corresponds to the JSON property package



2640
2641
2642
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2640

def package
  @package
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


2645
2646
2647
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2645

def remediation
  @remediation
end

#resource_uriString

Required. Immutable. A URI that represents the resource for which the occurrence applies. For example, https://gcr.io/project/image@sha256:123abc for a Docker image. Corresponds to the JSON property resourceUri

Returns:

  • (String)


2652
2653
2654
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2652

def resource_uri
  @resource_uri
end

#sbom_referenceGoogle::Apis::OndemandscanningV1beta1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



2659
2660
2661
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2659

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::OndemandscanningV1beta1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



2664
2665
2666
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2664

def secret
  @secret
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2669
2670
2671
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2669

def update_time
  @update_time
end

#upgradeGoogle::Apis::OndemandscanningV1beta1::UpgradeOccurrence

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update. Corresponds to the JSON property upgrade



2678
2679
2680
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2678

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::OndemandscanningV1beta1::VulnerabilityOccurrence

An occurrence of a severity vulnerability on a resource. Corresponds to the JSON property vulnerability



2683
2684
2685
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2683

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2690

def update!(**args)
  @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @envelope = args[:envelope] if args.key?(:envelope)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @package = args[:package] if args.key?(:package)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end