Class: Google::Apis::OndemandscanningV1beta1::PackageOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Details on how a particular software package was installed on a system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageOccurrence

Returns a new instance of PackageOccurrence.



3040
3041
3042
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages. Corresponds to the JSON property architecture

Returns:

  • (String)


3004
3005
3006
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3004

def architecture
  @architecture
end

#cpe_uriString

Output only. The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages. Corresponds to the JSON property cpeUri

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3011

def cpe_uri
  @cpe_uri
end

#licenseGoogle::Apis::OndemandscanningV1beta1::License

License information. Corresponds to the JSON property license



3016
3017
3018
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3016

def license
  @license
end

#locationArray<Google::Apis::OndemandscanningV1beta1::Location>

All of the places within the filesystem versions of this package have been found. Corresponds to the JSON property location



3022
3023
3024
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3022

def location
  @location
end

#nameString

Required. Output only. The name of the installed package. Corresponds to the JSON property name

Returns:

  • (String)


3027
3028
3029
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3027

def name
  @name
end

#package_typeString

Output only. The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property packageType

Returns:

  • (String)


3033
3034
3035
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3033

def package_type
  @package_type
end

#versionGoogle::Apis::OndemandscanningV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



3038
3039
3040
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3038

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3045

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @license = args[:license] if args.key?(:license)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @version = args[:version] if args.key?(:version)
end