Class: Google::Apis::OndemandscanningV1beta1::PackageVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageVersion

Returns a new instance of PackageVersion.



3078
3079
3080
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licensesArray<String>

The licenses associated with this package. Note that this has to go on the PackageVersion level, because we can have cases with images with the same source having different licences. E.g. in Alpine, musl and musl-utils both have the same origin musl, but have different sets of licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


3066
3067
3068
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3066

def licenses
  @licenses
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


3071
3072
3073
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3071

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


3076
3077
3078
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3076

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3083
3084
3085
3086
3087
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3083

def update!(**args)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end