Class: Google::Apis::OndemandscanningV1beta1::Risk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Risk

Returns a new instance of Risk.



3399
3400
3401
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cisa_kevGoogle::Apis::OndemandscanningV1beta1::CisaKnownExploitedVulnerabilities

CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild. Corresponds to the JSON property cisaKev



3391
3392
3393
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3391

def cisa_kev
  @cisa_kev
end

#epssGoogle::Apis::OndemandscanningV1beta1::ExploitPredictionScoringSystem

The Exploit Prediction Scoring System (EPSS) estimates the likelihood ( probability) that a software vulnerability will be exploited in the wild. Corresponds to the JSON property epss



3397
3398
3399
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3397

def epss
  @epss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3404
3405
3406
3407
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3404

def update!(**args)
  @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev)
  @epss = args[:epss] if args.key?(:epss)
end