Class: Google::Apis::OndemandscanningV1beta1::SbomReferenceIntotoPayload
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::SbomReferenceIntotoPayload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
The actual payload that contains the SBOM Reference data. The payload follows the intoto statement specification. See https://github.com/in-toto/attestation/ blob/main/spec/v1.0/statement.md for more details.
Instance Attribute Summary collapse
-
#_type ⇒ String
Identifier for the schema of the Statement.
-
#predicate ⇒ Google::Apis::OndemandscanningV1beta1::SbomReferenceIntotoPredicate
A predicate which describes the SBOM being referenced.
-
#predicate_type ⇒ String
URI identifying the type of the Predicate.
-
#subject ⇒ Array<Google::Apis::OndemandscanningV1beta1::Subject>
Set of software artifacts that the attestation applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SbomReferenceIntotoPayload
constructor
A new instance of SbomReferenceIntotoPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SbomReferenceIntotoPayload
Returns a new instance of SbomReferenceIntotoPayload.
3300 3301 3302 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#_type ⇒ String
Identifier for the schema of the Statement.
Corresponds to the JSON property _type
3282 3283 3284 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3282 def _type @_type end |
#predicate ⇒ Google::Apis::OndemandscanningV1beta1::SbomReferenceIntotoPredicate
A predicate which describes the SBOM being referenced.
Corresponds to the JSON property predicate
3287 3288 3289 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3287 def predicate @predicate end |
#predicate_type ⇒ String
URI identifying the type of the Predicate.
Corresponds to the JSON property predicateType
3292 3293 3294 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3292 def predicate_type @predicate_type end |
#subject ⇒ Array<Google::Apis::OndemandscanningV1beta1::Subject>
Set of software artifacts that the attestation applies to. Each element
represents a single software artifact.
Corresponds to the JSON property subject
3298 3299 3300 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3298 def subject @subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3305 3306 3307 3308 3309 3310 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3305 def update!(**args) @_type = args[:_type] if args.key?(:_type) @predicate = args[:predicate] if args.key?(:predicate) @predicate_type = args[:predicate_type] if args.key?(:predicate_type) @subject = args[:subject] if args.key?(:subject) end |