Class: Google::Apis::OndemandscanningV1beta1::SbomReferenceIntotoPredicate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

A predicate which describes the SBOM being referenced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SbomReferenceIntotoPredicate

Returns a new instance of SbomReferenceIntotoPredicate.



3449
3450
3451
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

A map of algorithm to digest of the contents of the SBOM. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


3432
3433
3434
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3432

def digest
  @digest
end

#locationString

The location of the SBOM. Corresponds to the JSON property location

Returns:

  • (String)


3437
3438
3439
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3437

def location
  @location
end

#mime_typeString

The mime type of the SBOM. Corresponds to the JSON property mimeType

Returns:

  • (String)


3442
3443
3444
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3442

def mime_type
  @mime_type
end

#referrer_idString

The person or system referring this predicate to the consumer. Corresponds to the JSON property referrerId

Returns:

  • (String)


3447
3448
3449
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3447

def referrer_id
  @referrer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3454
3455
3456
3457
3458
3459
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3454

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @location = args[:location] if args.key?(:location)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @referrer_id = args[:referrer_id] if args.key?(:referrer_id)
end