Class: Google::Apis::OndemandscanningV1beta1::SlsaMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Other properties of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaMetadata

Returns a new instance of SlsaMetadata.



3806
3807
3808
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_finished_onString

The timestamp of when the build completed. Corresponds to the JSON property buildFinishedOn

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3779

def build_finished_on
  @build_finished_on
end

#build_invocation_idString

Identifies the particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis. The value SHOULD be globally unique, per in-toto Provenance spec. Corresponds to the JSON property buildInvocationId

Returns:

  • (String)


3786
3787
3788
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3786

def build_invocation_id
  @build_invocation_id
end

#build_started_onString

The timestamp of when the build started. Corresponds to the JSON property buildStartedOn

Returns:

  • (String)


3791
3792
3793
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3791

def build_started_on
  @build_started_on
end

#completenessGoogle::Apis::OndemandscanningV1beta1::SlsaCompleteness

Indicates that the builder claims certain fields in this message to be complete. Corresponds to the JSON property completeness



3797
3798
3799
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3797

def completeness
  @completeness
end

#reproducibleBoolean Also known as: reproducible?

If true, the builder claims that running the recipe on materials will produce bit-for-bit identical output. Corresponds to the JSON property reproducible

Returns:

  • (Boolean)


3803
3804
3805
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3803

def reproducible
  @reproducible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3811
3812
3813
3814
3815
3816
3817
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3811

def update!(**args)
  @build_finished_on = args[:build_finished_on] if args.key?(:build_finished_on)
  @build_invocation_id = args[:build_invocation_id] if args.key?(:build_invocation_id)
  @build_started_on = args[:build_started_on] if args.key?(:build_started_on)
  @completeness = args[:completeness] if args.key?(:completeness)
  @reproducible = args[:reproducible] if args.key?(:reproducible)
end