Class: Google::Apis::OndemandscanningV1beta1::SlsaRecipe
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::SlsaRecipe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe.
Instance Attribute Summary collapse
-
#arguments ⇒ Hash<String,Object>
Collection of all external inputs that influenced the build on top of recipe.
-
#defined_in_material ⇒ Fixnum
Index in materials containing the recipe steps that are not implied by recipe.
-
#entry_point ⇒ String
String identifying the entry point into the build.
-
#environment ⇒ Hash<String,Object>
Any other builder-controlled inputs necessary for correctly evaluating the recipe.
-
#type ⇒ String
URI indicating what type of recipe was performed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaRecipe
constructor
A new instance of SlsaRecipe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaRecipe
Returns a new instance of SlsaRecipe.
3865 3866 3867 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Hash<String,Object>
Collection of all external inputs that influenced the build on top of recipe.
definedInMaterial and recipe.entryPoint. For example, if the recipe type were "
make", then this might be the flags passed to make aside from the target,
which is captured in recipe.entryPoint. Depending on the recipe Type, the
structure may be different.
Corresponds to the JSON property arguments
3832 3833 3834 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3832 def arguments @arguments end |
#defined_in_material ⇒ Fixnum
Index in materials containing the recipe steps that are not implied by recipe.
type. For example, if the recipe type were "make", then this would point to
the source containing the Makefile, not the make program itself. Set to -1 if
the recipe doesn't come from a material, as zero is default unset value for
int64.
Corresponds to the JSON property definedInMaterial
3841 3842 3843 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3841 def defined_in_material @defined_in_material end |
#entry_point ⇒ String
String identifying the entry point into the build. This is often a path to a
configuration file and/or a target label within that file. The syntax and
meaning are defined by recipe.type. For example, if the recipe type were "make"
, then this would reference the directory in which to run make as well as
which target to use.
Corresponds to the JSON property entryPoint
3850 3851 3852 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3850 def entry_point @entry_point end |
#environment ⇒ Hash<String,Object>
Any other builder-controlled inputs necessary for correctly evaluating the
recipe. Usually only needed for reproducing the build but not evaluated as
part of policy. Depending on the recipe Type, the structure may be different.
Corresponds to the JSON property environment
3857 3858 3859 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3857 def environment @environment end |
#type ⇒ String
URI indicating what type of recipe was performed. It determines the meaning of
recipe.entryPoint, recipe.arguments, recipe.environment, and materials.
Corresponds to the JSON property type
3863 3864 3865 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3863 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3870 3871 3872 3873 3874 3875 3876 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3870 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @defined_in_material = args[:defined_in_material] if args.key?(:defined_in_material) @entry_point = args[:entry_point] if args.key?(:entry_point) @environment = args[:environment] if args.key?(:environment) @type = args[:type] if args.key?(:type) end |