Class: Google::Apis::OndemandscanningV1beta1::Source
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::Source
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Source describes the location of the source used for the build.
Instance Attribute Summary collapse
-
#additional_contexts ⇒ Array<Google::Apis::OndemandscanningV1beta1::SourceContext>
If provided, some of the source code used for the build may be found in these locations, in the case where the source repository had multiple remotes or submodules.
-
#artifact_storage_source_uri ⇒ String
If provided, the input binary artifacts for the build came from this location.
-
#context ⇒ Google::Apis::OndemandscanningV1beta1::SourceContext
A SourceContext is a reference to a tree of files.
-
#file_hashes ⇒ Hash<String,Google::Apis::OndemandscanningV1beta1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
3911 3912 3913 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_contexts ⇒ Array<Google::Apis::OndemandscanningV1beta1::SourceContext>
If provided, some of the source code used for the build may be found in these
locations, in the case where the source repository had multiple remotes or
submodules. This list will not include the context specified in the context
field.
Corresponds to the JSON property additionalContexts
3889 3890 3891 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3889 def additional_contexts @additional_contexts end |
#artifact_storage_source_uri ⇒ String
If provided, the input binary artifacts for the build came from this location.
Corresponds to the JSON property artifactStorageSourceUri
3894 3895 3896 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3894 def artifact_storage_source_uri @artifact_storage_source_uri end |
#context ⇒ Google::Apis::OndemandscanningV1beta1::SourceContext
A SourceContext is a reference to a tree of files. A SourceContext together
with a path point to a unique revision of a single file or directory.
Corresponds to the JSON property context
3900 3901 3902 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3900 def context @context end |
#file_hashes ⇒ Hash<String,Google::Apis::OndemandscanningV1beta1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original
source integrity was maintained in the build. The keys to this map are file
paths used as build source and the values contain the hash values for those
files. If the build source came in a single package such as a gzipped tarfile (
.tar.gz), the FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
3909 3910 3911 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3909 def file_hashes @file_hashes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3916 3917 3918 3919 3920 3921 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3916 def update!(**args) @additional_contexts = args[:additional_contexts] if args.key?(:additional_contexts) @artifact_storage_source_uri = args[:artifact_storage_source_uri] if args.key?(:artifact_storage_source_uri) @context = args[:context] if args.key?(:context) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) end |