Class: Google::Apis::OndemandscanningV1beta1::SourceContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceContext

Returns a new instance of SourceContext.



4069
4070
4071
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_repoGoogle::Apis::OndemandscanningV1beta1::CloudRepoSourceContext

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo. Corresponds to the JSON property cloudRepo



4051
4052
4053
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4051

def cloud_repo
  @cloud_repo
end

#gerritGoogle::Apis::OndemandscanningV1beta1::GerritSourceContext

A SourceContext referring to a Gerrit project. Corresponds to the JSON property gerrit



4056
4057
4058
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4056

def gerrit
  @gerrit
end

#gitGoogle::Apis::OndemandscanningV1beta1::GitSourceContext

A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub). Corresponds to the JSON property git



4062
4063
4064
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4062

def git
  @git
end

#labelsHash<String,String>

Labels with user defined metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4067
4068
4069
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4067

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4074
4075
4076
4077
4078
4079
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4074

def update!(**args)
  @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo)
  @gerrit = args[:gerrit] if args.key?(:gerrit)
  @git = args[:git] if args.key?(:git)
  @labels = args[:labels] if args.key?(:labels)
end