Class: Google::Apis::OndemandscanningV1beta1::UpgradeDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeDistribution

Returns a new instance of UpgradeDistribution.



4177
4178
4179
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. For Windows the classification is one of the category_ids listed at https://docs.microsoft.com/en-us/previous- versions/windows/desktop/ff357803(v=vs.85) Corresponds to the JSON property classification

Returns:

  • (String)


4159
4160
4161
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4159

def classification
  @classification
end

#cpe_uriString

Required - The specific operating system this metadata applies to. See https:// cpe.mitre.org/specification/. Corresponds to the JSON property cpeUri

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4165

def cpe_uri
  @cpe_uri
end

#cveArray<String>

The cve tied to this Upgrade. Corresponds to the JSON property cve

Returns:

  • (Array<String>)


4170
4171
4172
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4170

def cve
  @cve
end

#severityString

The severity as specified by the upstream operating system. Corresponds to the JSON property severity

Returns:

  • (String)


4175
4176
4177
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4175

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4182
4183
4184
4185
4186
4187
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4182

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @cve = args[:cve] if args.key?(:cve)
  @severity = args[:severity] if args.key?(:severity)
end