Class: Google::Apis::OndemandscanningV1beta1::UpgradeOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeOccurrence

Returns a new instance of UpgradeOccurrence.



4223
4224
4225
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distributionGoogle::Apis::OndemandscanningV1beta1::UpgradeDistribution

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities. Corresponds to the JSON property distribution



4203
4204
4205
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4203

def distribution
  @distribution
end

#packageString

Required for non-Windows OS. The package this Upgrade is for. Corresponds to the JSON property package

Returns:

  • (String)


4208
4209
4210
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4208

def package
  @package
end

#parsed_versionGoogle::Apis::OndemandscanningV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property parsedVersion



4213
4214
4215
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4213

def parsed_version
  @parsed_version
end

#windows_updateGoogle::Apis::OndemandscanningV1beta1::WindowsUpdate

Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate. Corresponds to the JSON property windowsUpdate



4221
4222
4223
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4221

def windows_update
  @windows_update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4228
4229
4230
4231
4232
4233
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4228

def update!(**args)
  @distribution = args[:distribution] if args.key?(:distribution)
  @package = args[:package] if args.key?(:package)
  @parsed_version = args[:parsed_version] if args.key?(:parsed_version)
  @windows_update = args[:windows_update] if args.key?(:windows_update)
end