Class: Google::Apis::OndemandscanningV1beta1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



4277
4278
4279
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


4243
4244
4245
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4243

def epoch
  @epoch
end

#full_nameString

Human readable version string. This string is of the form :- and is only set when kind is NORMAL. Corresponds to the JSON property fullName

Returns:

  • (String)


4249
4250
4251
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4249

def full_name
  @full_name
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


4259
4260
4261
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4259

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


4265
4266
4267
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4265

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


4270
4271
4272
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4270

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


4275
4276
4277
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4275

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4282

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @full_name = args[:full_name] if args.key?(:full_name)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end