Class: Google::Apis::OndemandscanningV1beta1::VexAssessment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

VexAssessment provides all publisher provided Vex information that is related to this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VexAssessment

Returns a new instance of VexAssessment.



4226
4227
4228
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs. Corresponds to the JSON property cve

Returns:

  • (String)


4184
4185
4186
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4184

def cve
  @cve
end

#impactsArray<String>

Contains information about the impact of this vulnerability, this will change with time. Corresponds to the JSON property impacts

Returns:

  • (Array<String>)


4190
4191
4192
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4190

def impacts
  @impacts
end

#justificationGoogle::Apis::OndemandscanningV1beta1::Justification

Justification provides the justification when the state of the assessment if NOT_AFFECTED. Corresponds to the JSON property justification



4196
4197
4198
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4196

def justification
  @justification
end

#note_nameString

The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID]. Corresponds to the JSON property noteName

Returns:

  • (String)


4202
4203
4204
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4202

def note_name
  @note_name
end

Holds a list of references associated with this vulnerability item and assessment. Corresponds to the JSON property relatedUris



4208
4209
4210
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4208

def related_uris
  @related_uris
end

#remediationsArray<Google::Apis::OndemandscanningV1beta1::Remediation>

Specifies details on how to handle (and presumably, fix) a vulnerability. Corresponds to the JSON property remediations



4213
4214
4215
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4213

def remediations
  @remediations
end

#stateString

Provides the state of this Vulnerability assessment. Corresponds to the JSON property state

Returns:

  • (String)


4218
4219
4220
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4218

def state
  @state
end

#vulnerability_idString

The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc. Corresponds to the JSON property vulnerabilityId

Returns:

  • (String)


4224
4225
4226
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4224

def vulnerability_id
  @vulnerability_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4231

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @impacts = args[:impacts] if args.key?(:impacts)
  @justification = args[:justification] if args.key?(:justification)
  @note_name = args[:note_name] if args.key?(:note_name)
  @related_uris = args[:related_uris] if args.key?(:related_uris)
  @remediations = args[:remediations] if args.key?(:remediations)
  @state = args[:state] if args.key?(:state)
  @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id)
end