Class: Google::Apis::OndemandscanningV1beta1::VulnerabilityOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

An occurrence of a severity vulnerability on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityOccurrence

Returns a new instance of VulnerabilityOccurrence.



4466
4467
4468
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvss_scoreFloat

Output only. The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssScore

Returns:

  • (Float)


4369
4370
4371
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4369

def cvss_score
  @cvss_score
end

#cvss_v2Google::Apis::OndemandscanningV1beta1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssV2



4377
4378
4379
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4377

def cvss_v2
  @cvss_v2
end

#cvss_v4Google::Apis::OndemandscanningV1beta1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssV4



4385
4386
4387
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4385

def cvss_v4
  @cvss_v4
end

#cvss_versionString

Output only. CVSS version used to populate cvss_score and severity. Corresponds to the JSON property cvssVersion

Returns:

  • (String)


4390
4391
4392
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4390

def cvss_version
  @cvss_version
end

#cvssv3Google::Apis::OndemandscanningV1beta1::Cvss

Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version. Corresponds to the JSON property cvssv3



4398
4399
4400
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4398

def cvssv3
  @cvssv3
end

#effective_severityString

The distro assigned severity for this vulnerability when it is available, otherwise this is the note provider assigned severity. When there are multiple PackageIssues for this vulnerability, they can have different effective severities because some might be provided by the distro while others are provided by the language ecosystem for a language pack. For this reason, it is advised to use the effective severity on the PackageIssue level. In the case where multiple PackageIssues have differing effective severities, this field should be the highest severity for any of the PackageIssues. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


4410
4411
4412
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4410

def effective_severity
  @effective_severity
end

#extra_detailsString

Occurrence-specific extra details about the vulnerability. Corresponds to the JSON property extraDetails

Returns:

  • (String)


4415
4416
4417
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4415

def extra_details
  @extra_details
end

#fix_availableBoolean Also known as: fix_available?

Output only. Whether at least one of the affected packages has a fix available. Corresponds to the JSON property fixAvailable

Returns:

  • (Boolean)


4420
4421
4422
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4420

def fix_available
  @fix_available
end

#long_descriptionString

Output only. A detailed description of this vulnerability. Corresponds to the JSON property longDescription

Returns:

  • (String)


4426
4427
4428
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4426

def long_description
  @long_description
end

#package_issueArray<Google::Apis::OndemandscanningV1beta1::PackageIssue>

Required. The set of affected locations and their fixes (if available) within the associated resource. Corresponds to the JSON property packageIssue



4432
4433
4434
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4432

def package_issue
  @package_issue
end

Output only. URLs related to this vulnerability. Corresponds to the JSON property relatedUrls



4437
4438
4439
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4437

def related_urls
  @related_urls
end

#riskGoogle::Apis::OndemandscanningV1beta1::Risk

Risk information about the vulnerability, such as CISA, EPSS, etc. Corresponds to the JSON property risk



4442
4443
4444
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4442

def risk
  @risk
end

#severityString

Output only. The note provider assigned severity of this vulnerability. Corresponds to the JSON property severity

Returns:

  • (String)


4447
4448
4449
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4447

def severity
  @severity
end

#short_descriptionString

Output only. A one sentence description of this vulnerability. Corresponds to the JSON property shortDescription

Returns:

  • (String)


4452
4453
4454
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4452

def short_description
  @short_description
end

#typeString

The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.). Corresponds to the JSON property type

Returns:

  • (String)


4458
4459
4460
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4458

def type
  @type
end

#vex_assessmentGoogle::Apis::OndemandscanningV1beta1::VexAssessment

VexAssessment provides all publisher provided Vex information that is related to this vulnerability. Corresponds to the JSON property vexAssessment



4464
4465
4466
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4464

def vex_assessment
  @vex_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
4481
4482
4483
4484
4485
4486
4487
4488
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4471

def update!(**args)
  @cvss_score = args[:cvss_score] if args.key?(:cvss_score)
  @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2)
  @cvss_v4 = args[:cvss_v4] if args.key?(:cvss_v4)
  @cvss_version = args[:cvss_version] if args.key?(:cvss_version)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @extra_details = args[:extra_details] if args.key?(:extra_details)
  @fix_available = args[:fix_available] if args.key?(:fix_available)
  @long_description = args[:long_description] if args.key?(:long_description)
  @package_issue = args[:package_issue] if args.key?(:package_issue)
  @related_urls = args[:related_urls] if args.key?(:related_urls)
  @risk = args[:risk] if args.key?(:risk)
  @severity = args[:severity] if args.key?(:severity)
  @short_description = args[:short_description] if args.key?(:short_description)
  @type = args[:type] if args.key?(:type)
  @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment)
end