Class: Google::Apis::OndemandscanningV1beta1::BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BaseImage
constructor
A new instance of BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BaseImage
Returns a new instance of BaseImage.
291 292 293 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
279 280 281 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 279 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
284 285 286 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 284 def name @name end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
289 290 291 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 289 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
296 297 298 299 300 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 296 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @repository = args[:repository] if args.key?(:repository) end |