Class: Google::Apis::OndemandscanningV1beta1::BinarySourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BinarySourceInfo

Returns a new instance of BinarySourceInfo.



354
355
356
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binary_versionGoogle::Apis::OndemandscanningV1beta1::PackageVersion

The binary package. This is significant when the source is different than the binary itself. Historically if they've differed, we've stored the name of the source and its version in the package/version fields, but we should also store the binary package info, as that's what's actually installed. Corresponds to the JSON property binaryVersion



344
345
346
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 344

def binary_version
  @binary_version
end

#source_versionGoogle::Apis::OndemandscanningV1beta1::PackageVersion

The source package. Similar to the above, this is significant when the source is different than the binary itself. Since the top-level package/version fields are based on an if/else, we need a separate field for both binary and source if we want to know definitively where the data is coming from. Corresponds to the JSON property sourceVersion



352
353
354
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 352

def source_version
  @source_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



359
360
361
362
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 359

def update!(**args)
  @binary_version = args[:binary_version] if args.key?(:binary_version)
  @source_version = args[:source_version] if args.key?(:source_version)
end