Class: Google::Apis::OndemandscanningV1beta1::BinarySourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::BinarySourceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#binary_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
The binary package.
-
#source_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
The source package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BinarySourceInfo
constructor
A new instance of BinarySourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BinarySourceInfo
Returns a new instance of BinarySourceInfo.
323 324 325 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binary_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
The binary package. This is significant when the source is different than the
binary itself. Historically if they've differed, we've stored the name of the
source and its version in the package/version fields, but we should also store
the binary package info, as that's what's actually installed.
Corresponds to the JSON property binaryVersion
313 314 315 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 313 def binary_version @binary_version end |
#source_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
The source package. Similar to the above, this is significant when the source
is different than the binary itself. Since the top-level package/version
fields are based on an if/else, we need a separate field for both binary and
source if we want to know definitively where the data is coming from.
Corresponds to the JSON property sourceVersion
321 322 323 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 321 def source_version @source_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
328 329 330 331 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 328 def update!(**args) @binary_version = args[:binary_version] if args.key?(:binary_version) @source_version = args[:source_version] if args.key?(:source_version) end |