Class: Google::Apis::OndemandscanningV1beta1::Cvss
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::Cvss
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version.
Instance Attribute Summary collapse
-
#attack_complexity ⇒ String
Attack Complexity (AC).
-
#attack_requirements ⇒ String
Attack Requirements (AT).
-
#attack_vector ⇒ String
Attack Vector (AV).
-
#authentication ⇒ String
Authentication (Au).
-
#availability_impact ⇒ String
Availability Impact (A).
-
#base_score ⇒ Float
The base score is a function of the base metric scores.
-
#confidentiality_impact ⇒ String
Confidentiality Impact (C).
-
#exploitability_score ⇒ Float
Corresponds to the JSON property
exploitabilityScore. -
#impact_score ⇒ Float
Corresponds to the JSON property
impactScore. -
#integrity_impact ⇒ String
Integrity Impact (I).
-
#privileges_required ⇒ String
Privileges Required (PR).
-
#scope ⇒ String
Scope (S).
-
#subsequent_system_availability_impact ⇒ String
Subsequent System Availability Impact (SA).
-
#subsequent_system_confidentiality_impact ⇒ String
Subsequent System Confidentiality Impact (SC).
-
#subsequent_system_integrity_impact ⇒ String
Subsequent System Integrity Impact (SI).
-
#user_interaction ⇒ String
User Interaction (UI).
-
#vulnerable_system_availability_impact ⇒ String
Vulnerable System Availability Impact (VA).
-
#vulnerable_system_confidentiality_impact ⇒ String
Vulnerable System Confidentiality Impact (VC).
-
#vulnerable_system_integrity_impact ⇒ String
Vulnerable System Integrity Impact (VI).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cvss
constructor
A new instance of Cvss.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cvss
Returns a new instance of Cvss.
731 732 733 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_complexity ⇒ String
Attack Complexity (AC). Defined in CVSS v2, v3, v4.
Corresponds to the JSON property attackComplexity
639 640 641 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 639 def attack_complexity @attack_complexity end |
#attack_requirements ⇒ String
Attack Requirements (AT). Defined in CVSS v4.
Corresponds to the JSON property attackRequirements
644 645 646 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 644 def attack_requirements @attack_requirements end |
#attack_vector ⇒ String
Attack Vector (AV). Defined in CVSS v2, v3, v4.
Corresponds to the JSON property attackVector
649 650 651 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 649 def attack_vector @attack_vector end |
#authentication ⇒ String
Authentication (Au). Defined in CVSS v2.
Corresponds to the JSON property authentication
654 655 656 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 654 def authentication @authentication end |
#availability_impact ⇒ String
Availability Impact (A). Defined in CVSS v2, v3.
Corresponds to the JSON property availabilityImpact
659 660 661 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 659 def availability_impact @availability_impact end |
#base_score ⇒ Float
The base score is a function of the base metric scores.
Corresponds to the JSON property baseScore
664 665 666 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 664 def base_score @base_score end |
#confidentiality_impact ⇒ String
Confidentiality Impact (C). Defined in CVSS v2, v3.
Corresponds to the JSON property confidentialityImpact
669 670 671 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 669 def confidentiality_impact @confidentiality_impact end |
#exploitability_score ⇒ Float
Corresponds to the JSON property exploitabilityScore
674 675 676 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 674 def exploitability_score @exploitability_score end |
#impact_score ⇒ Float
Corresponds to the JSON property impactScore
679 680 681 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 679 def impact_score @impact_score end |
#integrity_impact ⇒ String
Integrity Impact (I). Defined in CVSS v2, v3.
Corresponds to the JSON property integrityImpact
684 685 686 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 684 def integrity_impact @integrity_impact end |
#privileges_required ⇒ String
Privileges Required (PR). Defined in CVSS v3, v4.
Corresponds to the JSON property privilegesRequired
689 690 691 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 689 def privileges_required @privileges_required end |
#scope ⇒ String
Scope (S). Defined in CVSS v3.
Corresponds to the JSON property scope
694 695 696 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 694 def scope @scope end |
#subsequent_system_availability_impact ⇒ String
Subsequent System Availability Impact (SA). Defined in CVSS v4.
Corresponds to the JSON property subsequentSystemAvailabilityImpact
699 700 701 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 699 def subsequent_system_availability_impact @subsequent_system_availability_impact end |
#subsequent_system_confidentiality_impact ⇒ String
Subsequent System Confidentiality Impact (SC). Defined in CVSS v4.
Corresponds to the JSON property subsequentSystemConfidentialityImpact
704 705 706 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 704 def subsequent_system_confidentiality_impact @subsequent_system_confidentiality_impact end |
#subsequent_system_integrity_impact ⇒ String
Subsequent System Integrity Impact (SI). Defined in CVSS v4.
Corresponds to the JSON property subsequentSystemIntegrityImpact
709 710 711 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 709 def subsequent_system_integrity_impact @subsequent_system_integrity_impact end |
#user_interaction ⇒ String
User Interaction (UI). Defined in CVSS v3, v4.
Corresponds to the JSON property userInteraction
714 715 716 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 714 def user_interaction @user_interaction end |
#vulnerable_system_availability_impact ⇒ String
Vulnerable System Availability Impact (VA). Defined in CVSS v4.
Corresponds to the JSON property vulnerableSystemAvailabilityImpact
719 720 721 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 719 def vulnerable_system_availability_impact @vulnerable_system_availability_impact end |
#vulnerable_system_confidentiality_impact ⇒ String
Vulnerable System Confidentiality Impact (VC). Defined in CVSS v4.
Corresponds to the JSON property vulnerableSystemConfidentialityImpact
724 725 726 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 724 def vulnerable_system_confidentiality_impact @vulnerable_system_confidentiality_impact end |
#vulnerable_system_integrity_impact ⇒ String
Vulnerable System Integrity Impact (VI). Defined in CVSS v4.
Corresponds to the JSON property vulnerableSystemIntegrityImpact
729 730 731 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 729 def vulnerable_system_integrity_impact @vulnerable_system_integrity_impact end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 736 def update!(**args) @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity) @attack_requirements = args[:attack_requirements] if args.key?(:attack_requirements) @attack_vector = args[:attack_vector] if args.key?(:attack_vector) @authentication = args[:authentication] if args.key?(:authentication) @availability_impact = args[:availability_impact] if args.key?(:availability_impact) @base_score = args[:base_score] if args.key?(:base_score) @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact) @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score) @impact_score = args[:impact_score] if args.key?(:impact_score) @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact) @privileges_required = args[:privileges_required] if args.key?(:privileges_required) @scope = args[:scope] if args.key?(:scope) @subsequent_system_availability_impact = args[:subsequent_system_availability_impact] if args.key?(:subsequent_system_availability_impact) @subsequent_system_confidentiality_impact = args[:subsequent_system_confidentiality_impact] if args.key?(:subsequent_system_confidentiality_impact) @subsequent_system_integrity_impact = args[:subsequent_system_integrity_impact] if args.key?(:subsequent_system_integrity_impact) @user_interaction = args[:user_interaction] if args.key?(:user_interaction) @vulnerable_system_availability_impact = args[:vulnerable_system_availability_impact] if args.key?(:vulnerable_system_availability_impact) @vulnerable_system_confidentiality_impact = args[:vulnerable_system_confidentiality_impact] if args.key?(:vulnerable_system_confidentiality_impact) @vulnerable_system_integrity_impact = args[:vulnerable_system_integrity_impact] if args.key?(:vulnerable_system_integrity_impact) end |