Class: Google::Apis::OndemandscanningV1beta1::Cvss
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::Cvss
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Common Vulnerability Scoring System. For details, see https://www.first.org/ cvss/specification-document This is a message we will try to use for storing various versions of CVSS rather than making a separate proto for storing a specific version.
Instance Attribute Summary collapse
-
#attack_complexity ⇒ String
Corresponds to the JSON property
attackComplexity. -
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments.
-
#authentication ⇒ String
Corresponds to the JSON property
authentication. -
#availability_impact ⇒ String
Corresponds to the JSON property
availabilityImpact. -
#base_score ⇒ Float
The base score is a function of the base metric scores.
-
#confidentiality_impact ⇒ String
Corresponds to the JSON property
confidentialityImpact. -
#exploitability_score ⇒ Float
Corresponds to the JSON property
exploitabilityScore. -
#impact_score ⇒ Float
Corresponds to the JSON property
impactScore. -
#integrity_impact ⇒ String
Corresponds to the JSON property
integrityImpact. -
#privileges_required ⇒ String
Corresponds to the JSON property
privilegesRequired. -
#scope ⇒ String
Corresponds to the JSON property
scope. -
#user_interaction ⇒ String
Corresponds to the JSON property
userInteraction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cvss
constructor
A new instance of Cvss.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cvss
Returns a new instance of Cvss.
660 661 662 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_complexity ⇒ String
Corresponds to the JSON property attackComplexity
602 603 604 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 602 def attack_complexity @attack_complexity end |
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that
are constant over time and across user environments.
Corresponds to the JSON property attackVector
608 609 610 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 608 def attack_vector @attack_vector end |
#authentication ⇒ String
Corresponds to the JSON property authentication
613 614 615 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 613 def authentication @authentication end |
#availability_impact ⇒ String
Corresponds to the JSON property availabilityImpact
618 619 620 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 618 def availability_impact @availability_impact end |
#base_score ⇒ Float
The base score is a function of the base metric scores.
Corresponds to the JSON property baseScore
623 624 625 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 623 def base_score @base_score end |
#confidentiality_impact ⇒ String
Corresponds to the JSON property confidentialityImpact
628 629 630 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 628 def confidentiality_impact @confidentiality_impact end |
#exploitability_score ⇒ Float
Corresponds to the JSON property exploitabilityScore
633 634 635 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 633 def exploitability_score @exploitability_score end |
#impact_score ⇒ Float
Corresponds to the JSON property impactScore
638 639 640 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 638 def impact_score @impact_score end |
#integrity_impact ⇒ String
Corresponds to the JSON property integrityImpact
643 644 645 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 643 def integrity_impact @integrity_impact end |
#privileges_required ⇒ String
Corresponds to the JSON property privilegesRequired
648 649 650 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 648 def privileges_required @privileges_required end |
#scope ⇒ String
Corresponds to the JSON property scope
653 654 655 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 653 def scope @scope end |
#user_interaction ⇒ String
Corresponds to the JSON property userInteraction
658 659 660 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 658 def user_interaction @user_interaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 665 def update!(**args) @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity) @attack_vector = args[:attack_vector] if args.key?(:attack_vector) @authentication = args[:authentication] if args.key?(:authentication) @availability_impact = args[:availability_impact] if args.key?(:availability_impact) @base_score = args[:base_score] if args.key?(:base_score) @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact) @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score) @impact_score = args[:impact_score] if args.key?(:impact_score) @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact) @privileges_required = args[:privileges_required] if args.key?(:privileges_required) @scope = args[:scope] if args.key?(:scope) @user_interaction = args[:user_interaction] if args.key?(:user_interaction) end |