Class: Google::Apis::OndemandscanningV1beta1::DeploymentOccurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

The period during which some deployable was active in a runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentOccurrence

Returns a new instance of DeploymentOccurrence.



1048
1049
1050
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address of the runtime element hosting this deployment. Corresponds to the JSON property address

Returns:

  • (String)


1015
1016
1017
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1015

def address
  @address
end

#configString

Configuration used to create this deployment. Corresponds to the JSON property config

Returns:

  • (String)


1020
1021
1022
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1020

def config
  @config
end

#deploy_timeString

Required. Beginning of the lifetime of this deployment. Corresponds to the JSON property deployTime

Returns:

  • (String)


1025
1026
1027
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1025

def deploy_time
  @deploy_time
end

#platformString

Platform hosting this deployment. Corresponds to the JSON property platform

Returns:

  • (String)


1030
1031
1032
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1030

def platform
  @platform
end

#resource_uriArray<String>

Output only. Resource URI for the artifact being deployed taken from the deployable field with the same name. Corresponds to the JSON property resourceUri

Returns:

  • (Array<String>)


1036
1037
1038
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1036

def resource_uri
  @resource_uri
end

#undeploy_timeString

End of the lifetime of this deployment. Corresponds to the JSON property undeployTime

Returns:

  • (String)


1041
1042
1043
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1041

def undeploy_time
  @undeploy_time
end

#user_emailString

Identity of the user that triggered this deployment. Corresponds to the JSON property userEmail

Returns:

  • (String)


1046
1047
1048
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1046

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1053
1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1053

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @config = args[:config] if args.key?(:config)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @platform = args[:platform] if args.key?(:platform)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time)
  @user_email = args[:user_email] if args.key?(:user_email)
end