Class: Google::Apis::OndemandscanningV1beta1::DiscoveryOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::DiscoveryOccurrence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Provides information about the analysis status of a discovered resource.
Instance Attribute Summary collapse
-
#analysis_completed ⇒ Google::Apis::OndemandscanningV1beta1::AnalysisCompleted
Indicates which analysis completed successfully.
-
#analysis_error ⇒ Array<Google::Apis::OndemandscanningV1beta1::Status>
Indicates any errors encountered during analysis of a resource.
-
#analysis_status ⇒ String
The status of discovery for the resource.
-
#analysis_status_error ⇒ Google::Apis::OndemandscanningV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#archive_time ⇒ String
Output only.
-
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
-
#cpe ⇒ String
The CPE of the resource being scanned.
-
#files ⇒ Array<Google::Apis::OndemandscanningV1beta1::File>
Files that make up the resource described by the occurrence.
-
#last_scan_time ⇒ String
The last time this resource was scanned.
-
#sbom_status ⇒ Google::Apis::OndemandscanningV1beta1::SbomStatus
The status of an SBOM generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoveryOccurrence
constructor
A new instance of DiscoveryOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoveryOccurrence
Returns a new instance of DiscoveryOccurrence.
1042 1043 1044 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_completed ⇒ Google::Apis::OndemandscanningV1beta1::AnalysisCompleted
Indicates which analysis completed successfully. Multiple types of analysis
can be performed on a single resource.
Corresponds to the JSON property analysisCompleted
988 989 990 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 988 def analysis_completed @analysis_completed end |
#analysis_error ⇒ Array<Google::Apis::OndemandscanningV1beta1::Status>
Indicates any errors encountered during analysis of a resource. There could be
0 or more of these errors.
Corresponds to the JSON property analysisError
994 995 996 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 994 def analysis_error @analysis_error end |
#analysis_status ⇒ String
The status of discovery for the resource.
Corresponds to the JSON property analysisStatus
999 1000 1001 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 999 def analysis_status @analysis_status end |
#analysis_status_error ⇒ Google::Apis::OndemandscanningV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property analysisStatusError
1009 1010 1011 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1009 def analysis_status_error @analysis_status_error end |
#archive_time ⇒ String
Output only. The time occurrences related to this discovery occurrence were
archived.
Corresponds to the JSON property archiveTime
1015 1016 1017 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1015 def archive_time @archive_time end |
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
Corresponds to the JSON property continuousAnalysis
1020 1021 1022 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1020 def continuous_analysis @continuous_analysis end |
#cpe ⇒ String
The CPE of the resource being scanned.
Corresponds to the JSON property cpe
1025 1026 1027 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1025 def cpe @cpe end |
#files ⇒ Array<Google::Apis::OndemandscanningV1beta1::File>
Files that make up the resource described by the occurrence.
Corresponds to the JSON property files
1030 1031 1032 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1030 def files @files end |
#last_scan_time ⇒ String
The last time this resource was scanned.
Corresponds to the JSON property lastScanTime
1035 1036 1037 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1035 def last_scan_time @last_scan_time end |
#sbom_status ⇒ Google::Apis::OndemandscanningV1beta1::SbomStatus
The status of an SBOM generation.
Corresponds to the JSON property sbomStatus
1040 1041 1042 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1040 def sbom_status @sbom_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1047 def update!(**args) @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed) @analysis_error = args[:analysis_error] if args.key?(:analysis_error) @analysis_status = args[:analysis_status] if args.key?(:analysis_status) @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error) @archive_time = args[:archive_time] if args.key?(:archive_time) @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis) @cpe = args[:cpe] if args.key?(:cpe) @files = args[:files] if args.key?(:files) @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time) @sbom_status = args[:sbom_status] if args.key?(:sbom_status) end |