Class: Google::Apis::OndemandscanningV1beta1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



1235
1236
1237
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::OndemandscanningV1beta1::HashProp>

Required. Collection of file hashes. Corresponds to the JSON property fileHash



1233
1234
1235
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1233

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1240
1241
1242
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1240

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end