Class: Google::Apis::OndemandscanningV1beta1::FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::FileLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::OndemandscanningV1beta1::LayerDetails
Details about the layer a package was found in.
-
#line_number ⇒ Fixnum
Line number in the file where the package is found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileLocation
constructor
A new instance of FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileLocation
Returns a new instance of FileLocation.
1326 1327 1328 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
1312 1313 1314 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1312 def file_path @file_path end |
#layer_details ⇒ Google::Apis::OndemandscanningV1beta1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
1317 1318 1319 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1317 def layer_details @layer_details end |
#line_number ⇒ Fixnum
Line number in the file where the package is found. Applies only to source
repository scanning. Note: this field is marked as optional in other
corresponding protos, but in edition 2023, the "optional" keyword is redundant.
Corresponds to the JSON property lineNumber
1324 1325 1326 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1324 def line_number @line_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1331 1332 1333 1334 1335 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1331 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) @line_number = args[:line_number] if args.key?(:line_number) end |