Class: Google::Apis::OndemandscanningV1beta1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



1260
1261
1262
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1253

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::OndemandscanningV1beta1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



1258
1259
1260
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1258

def layer_details
  @layer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1265
1266
1267
1268
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1265

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
end