Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#registry ⇒ String
The registry in which the base image is from.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1BaseImage
constructor
A new instance of GrafeasV1BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1BaseImage
Returns a new instance of GrafeasV1BaseImage.
1511 1512 1513 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
1494 1495 1496 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1494 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
1499 1500 1501 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1499 def name @name end |
#registry ⇒ String
The registry in which the base image is from.
Corresponds to the JSON property registry
1504 1505 1506 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1504 def registry @registry end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
1509 1510 1511 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1509 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1516 1517 1518 1519 1520 1521 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1516 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @registry = args[:registry] if args.key?(:registry) @repository = args[:repository] if args.key?(:repository) end |