Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1BaseImage

Returns a new instance of GrafeasV1BaseImage.



1449
1450
1451
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#layer_countFixnum

The number of layers that the base image is composed of. Corresponds to the JSON property layerCount

Returns:

  • (Fixnum)


1432
1433
1434
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1432

def layer_count
  @layer_count
end

#nameString

The name of the base image. Corresponds to the JSON property name

Returns:

  • (String)


1437
1438
1439
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1437

def name
  @name
end

#registryString

The registry in which the base image is from. Corresponds to the JSON property registry

Returns:

  • (String)


1442
1443
1444
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1442

def registry
  @registry
end

#repositoryString

The repository name in which the base image is from. Corresponds to the JSON property repository

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1447

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1454
1455
1456
1457
1458
1459
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1454

def update!(**args)
  @layer_count = args[:layer_count] if args.key?(:layer_count)
  @name = args[:name] if args.key?(:name)
  @registry = args[:registry] if args.key?(:registry)
  @repository = args[:repository] if args.key?(:repository)
end