Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
BaseImage describes a base image of a container image.
Instance Attribute Summary collapse
-
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
-
#name ⇒ String
The name of the base image.
-
#repository ⇒ String
The repository name in which the base image is from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1BaseImage
constructor
A new instance of GrafeasV1BaseImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1BaseImage
Returns a new instance of GrafeasV1BaseImage.
1351 1352 1353 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#layer_count ⇒ Fixnum
The number of layers that the base image is composed of.
Corresponds to the JSON property layerCount
1339 1340 1341 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1339 def layer_count @layer_count end |
#name ⇒ String
The name of the base image.
Corresponds to the JSON property name
1344 1345 1346 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1344 def name @name end |
#repository ⇒ String
The repository name in which the base image is from.
Corresponds to the JSON property repository
1349 1350 1351 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1349 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1356 1357 1358 1359 1360 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1356 def update!(**args) @layer_count = args[:layer_count] if args.key?(:layer_count) @name = args[:name] if args.key?(:name) @repository = args[:repository] if args.key?(:repository) end |