Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::GrafeasV1FileLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails
Details about the layer a package was found in.
-
#line_number ⇒ Fixnum
Line number in the file where the package was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1FileLocation
constructor
A new instance of GrafeasV1FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1FileLocation
Returns a new instance of GrafeasV1FileLocation.
1545 1546 1547 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
1532 1533 1534 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1532 def file_path @file_path end |
#layer_details ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
1537 1538 1539 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1537 def layer_details @layer_details end |
#line_number ⇒ Fixnum
Line number in the file where the package was found. Optional field that only
applies to source repository scanning.
Corresponds to the JSON property lineNumber
1543 1544 1545 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1543 def line_number @line_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1550 1551 1552 1553 1554 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1550 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) @layer_details = args[:layer_details] if args.key?(:layer_details) @line_number = args[:line_number] if args.key?(:line_number) end |