Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1FileLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1FileLocation

Returns a new instance of GrafeasV1FileLocation.



1378
1379
1380
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1371

def file_path
  @file_path
end

#layer_detailsGoogle::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



1376
1377
1378
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1376

def layer_details
  @layer_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1383
1384
1385
1386
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1383

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
end