Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1LayerDetails

Returns a new instance of GrafeasV1LayerDetails.



1594
1595
1596
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



1570
1571
1572
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1570

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1576

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


1582
1583
1584
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1582

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


1587
1588
1589
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1587

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


1592
1593
1594
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1592

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1599
1600
1601
1602
1603
1604
1605
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1599

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end