Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1LayerDetails

Returns a new instance of GrafeasV1LayerDetails.



1420
1421
1422
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1beta1::GrafeasV1BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



1396
1397
1398
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1396

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


1402
1403
1404
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1402

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


1408
1409
1410
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1408

def command
  @command
end

#diff_idString

The diff ID (typically a sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1413

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


1418
1419
1420
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1418

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1425
1426
1427
1428
1429
1430
1431
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1425

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end