Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



1612
1613
1614
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


1610
1611
1612
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1610

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1617
1618
1619
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1617

def update!(**args)
  @id = args[:id] if args.key?(:id)
end