Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.



1550
1551
1552
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Corresponds to the JSON property id

Returns:

  • (String)


1548
1549
1550
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1548

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1555
1556
1557
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1555

def update!(**args)
  @id = args[:id] if args.key?(:id)
end