Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.
Instance Attribute Summary collapse
-
#id ⇒ String
Corresponds to the JSON property
id.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder.
1444 1445 1446 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Corresponds to the JSON property id
1442 1443 1444 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1442 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1449 1450 1451 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1449 def update!(**args) @id = args[:id] if args.key?(:id) end |