Class: Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Describes where the config file that kicked off the build came from. This is effectively a pointer to the source where buildConfig came from.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
Corresponds to the JSON property
digest. -
#entry_point ⇒ String
Corresponds to the JSON property
entryPoint. -
#uri ⇒ String
Corresponds to the JSON property
uri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
constructor
A new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource
Returns a new instance of GrafeasV1SlsaProvenanceZeroTwoSlsaConfigSource.
1677 1678 1679 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
Corresponds to the JSON property digest
1665 1666 1667 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1665 def digest @digest end |
#entry_point ⇒ String
Corresponds to the JSON property entryPoint
1670 1671 1672 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1670 def entry_point @entry_point end |
#uri ⇒ String
Corresponds to the JSON property uri
1675 1676 1677 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1675 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1682 1683 1684 1685 1686 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1682 def update!(**args) @digest = args[:digest] if args.key?(:digest) @entry_point = args[:entry_point] if args.key?(:entry_point) @uri = args[:uri] if args.key?(:uri) end |