Class: Google::Apis::OndemandscanningV1beta1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



1918
1919
1920
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::OndemandscanningV1beta1::BuilderConfig

required Corresponds to the JSON property builderConfig



1897
1898
1899
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1897

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


1905
1906
1907
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1905

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1beta1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



1910
1911
1912
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1910

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1beta1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



1916
1917
1918
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1916

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1923
1924
1925
1926
1927
1928
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1923

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end