Class: Google::Apis::OndemandscanningV1beta1::InTotoProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InTotoProvenance

Returns a new instance of InTotoProvenance.



1744
1745
1746
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builder_configGoogle::Apis::OndemandscanningV1beta1::BuilderConfig

required Corresponds to the JSON property builderConfig



1723
1724
1725
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1723

def builder_config
  @builder_config
end

#materialsArray<String>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


1731
1732
1733
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1731

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1beta1::Metadata

Other properties of the build. Corresponds to the JSON property metadata



1736
1737
1738
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1736

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1beta1::Recipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



1742
1743
1744
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1742

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1749
1750
1751
1752
1753
1754
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1749

def update!(**args)
  @builder_config = args[:builder_config] if args.key?(:builder_config)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end