Class: Google::Apis::OndemandscanningV1beta1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1beta1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
2189 2190 2191 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1beta1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
2165 2166 2167 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2165 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
2171 2172 2173 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2171 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
2177 2178 2179 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2177 def command @command end |
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
2182 2183 2184 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2182 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
2187 2188 2189 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2187 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2194 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |