Class: Google::Apis::OndemandscanningV1beta1::LayerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LayerDetails

Returns a new instance of LayerDetails.



2152
2153
2154
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imagesArray<Google::Apis::OndemandscanningV1beta1::BaseImage>

The base images the layer is found within. Corresponds to the JSON property baseImages



2128
2129
2130
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2128

def base_images
  @base_images
end

#chain_idString

The layer chain ID (sha256 hash) of the layer in the container image. https:// github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid Corresponds to the JSON property chainId

Returns:

  • (String)


2134
2135
2136
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2134

def chain_id
  @chain_id
end

#commandString

The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built. Corresponds to the JSON property command

Returns:

  • (String)


2140
2141
2142
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2140

def command
  @command
end

#diff_idString

The diff ID (sha256 hash) of the layer in the container image. Corresponds to the JSON property diffId

Returns:

  • (String)


2145
2146
2147
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2145

def diff_id
  @diff_id
end

#indexFixnum

The index of the layer in the container image. Corresponds to the JSON property index

Returns:

  • (Fixnum)


2150
2151
2152
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2150

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2157
2158
2159
2160
2161
2162
2163
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2157

def update!(**args)
  @base_images = args[:base_images] if args.key?(:base_images)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @command = args[:command] if args.key?(:command)
  @diff_id = args[:diff_id] if args.key?(:diff_id)
  @index = args[:index] if args.key?(:index)
end