Class: Google::Apis::OndemandscanningV1beta1::LayerDetails
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::LayerDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Details about the layer a package was found in.
Instance Attribute Summary collapse
-
#base_images ⇒ Array<Google::Apis::OndemandscanningV1beta1::BaseImage>
The base images the layer is found within.
-
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image.
-
#command ⇒ String
The layer build command that was used to build the layer.
-
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
-
#index ⇒ Fixnum
The index of the layer in the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayerDetails
constructor
A new instance of LayerDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LayerDetails
Returns a new instance of LayerDetails.
1978 1979 1980 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_images ⇒ Array<Google::Apis::OndemandscanningV1beta1::BaseImage>
The base images the layer is found within.
Corresponds to the JSON property baseImages
1954 1955 1956 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1954 def base_images @base_images end |
#chain_id ⇒ String
The layer chain ID (sha256 hash) of the layer in the container image. https://
github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
Corresponds to the JSON property chainId
1960 1961 1962 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1960 def chain_id @chain_id end |
#command ⇒ String
The layer build command that was used to build the layer. This may not be
found in all layers depending on how the container image is built.
Corresponds to the JSON property command
1966 1967 1968 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1966 def command @command end |
#diff_id ⇒ String
The diff ID (sha256 hash) of the layer in the container image.
Corresponds to the JSON property diffId
1971 1972 1973 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1971 def diff_id @diff_id end |
#index ⇒ Fixnum
The index of the layer in the container image.
Corresponds to the JSON property index
1976 1977 1978 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1976 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 1983 def update!(**args) @base_images = args[:base_images] if args.key?(:base_images) @chain_id = args[:chain_id] if args.key?(:chain_id) @command = args[:command] if args.key?(:command) @diff_id = args[:diff_id] if args.key?(:diff_id) @index = args[:index] if args.key?(:index) end |