Class: Google::Apis::OndemandscanningV1beta1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



2604
2605
2606
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advisory_publish_timeString

The time this advisory was published by the source. Corresponds to the JSON property advisoryPublishTime

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2475

def advisory_publish_time
  @advisory_publish_time
end

#ai_skill_analysisGoogle::Apis::OndemandscanningV1beta1::AiSkillAnalysisOccurrence

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



2480
2481
2482
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2480

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::OndemandscanningV1beta1::AttestationOccurrence

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for lookup (how to find this attestation if you already know the authority and artifact to be verified) and intent (for which authority this attestation was intended to sign. Corresponds to the JSON property attestation



2491
2492
2493
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2491

def attestation
  @attestation
end

#buildGoogle::Apis::OndemandscanningV1beta1::BuildOccurrence

Details of a build occurrence. Corresponds to the JSON property build



2496
2497
2498
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2496

def build
  @build
end

#complianceGoogle::Apis::OndemandscanningV1beta1::ComplianceOccurrence

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason. Corresponds to the JSON property compliance



2502
2503
2504
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2502

def compliance
  @compliance
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2507
2508
2509
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2507

def create_time
  @create_time
end

#deploymentGoogle::Apis::OndemandscanningV1beta1::DeploymentOccurrence

The period during which some deployable was active in a runtime. Corresponds to the JSON property deployment



2512
2513
2514
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2512

def deployment
  @deployment
end

#discoveryGoogle::Apis::OndemandscanningV1beta1::DiscoveryOccurrence

Provides information about the analysis status of a discovered resource. Corresponds to the JSON property discovery



2517
2518
2519
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2517

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::OndemandscanningV1beta1::DsseAttestationOccurrence

Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at the top level of the Occurrence. Corresponds to the JSON property dsseAttestation



2523
2524
2525
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2523

def dsse_attestation
  @dsse_attestation
end

#envelopeGoogle::Apis::OndemandscanningV1beta1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



2529
2530
2531
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2529

def envelope
  @envelope
end

#imageGoogle::Apis::OndemandscanningV1beta1::ImageOccurrence

Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM . Corresponds to the JSON property image



2535
2536
2537
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2535

def image
  @image
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


2541
2542
2543
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2541

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


2547
2548
2549
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2547

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


2554
2555
2556
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2554

def note_name
  @note_name
end

#packageGoogle::Apis::OndemandscanningV1beta1::PackageOccurrence

Details on how a particular software package was installed on a system. Corresponds to the JSON property package



2559
2560
2561
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2559

def package
  @package
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2564

def remediation
  @remediation
end

#resource_uriString

Required. Immutable. A URI that represents the resource for which the occurrence applies. For example, https://gcr.io/project/image@sha256:123abc for a Docker image. Corresponds to the JSON property resourceUri

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2571

def resource_uri
  @resource_uri
end

#sbom_referenceGoogle::Apis::OndemandscanningV1beta1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



2578
2579
2580
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2578

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::OndemandscanningV1beta1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



2583
2584
2585
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2583

def secret
  @secret
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2588

def update_time
  @update_time
end

#upgradeGoogle::Apis::OndemandscanningV1beta1::UpgradeOccurrence

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update. Corresponds to the JSON property upgrade



2597
2598
2599
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2597

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::OndemandscanningV1beta1::VulnerabilityOccurrence

An occurrence of a severity vulnerability on a resource. Corresponds to the JSON property vulnerability



2602
2603
2604
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2602

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2609

def update!(**args)
  @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @envelope = args[:envelope] if args.key?(:envelope)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @package = args[:package] if args.key?(:package)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end