Class: Google::Apis::OndemandscanningV1beta1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



2561
2562
2563
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advisory_publish_timeString

The time this advisory was published by the source. Corresponds to the JSON property advisoryPublishTime

Returns:

  • (String)


2432
2433
2434
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2432

def advisory_publish_time
  @advisory_publish_time
end

#ai_skill_analysisGoogle::Apis::OndemandscanningV1beta1::AiSkillAnalysisOccurrence

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



2437
2438
2439
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2437

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::OndemandscanningV1beta1::AttestationOccurrence

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for lookup (how to find this attestation if you already know the authority and artifact to be verified) and intent (for which authority this attestation was intended to sign. Corresponds to the JSON property attestation



2448
2449
2450
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2448

def attestation
  @attestation
end

#buildGoogle::Apis::OndemandscanningV1beta1::BuildOccurrence

Details of a build occurrence. Corresponds to the JSON property build



2453
2454
2455
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2453

def build
  @build
end

#complianceGoogle::Apis::OndemandscanningV1beta1::ComplianceOccurrence

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason. Corresponds to the JSON property compliance



2459
2460
2461
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2459

def compliance
  @compliance
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2464
2465
2466
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2464

def create_time
  @create_time
end

#deploymentGoogle::Apis::OndemandscanningV1beta1::DeploymentOccurrence

The period during which some deployable was active in a runtime. Corresponds to the JSON property deployment



2469
2470
2471
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2469

def deployment
  @deployment
end

#discoveryGoogle::Apis::OndemandscanningV1beta1::DiscoveryOccurrence

Provides information about the analysis status of a discovered resource. Corresponds to the JSON property discovery



2474
2475
2476
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2474

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::OndemandscanningV1beta1::DsseAttestationOccurrence

Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at the top level of the Occurrence. Corresponds to the JSON property dsseAttestation



2480
2481
2482
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2480

def dsse_attestation
  @dsse_attestation
end

#envelopeGoogle::Apis::OndemandscanningV1beta1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



2486
2487
2488
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2486

def envelope
  @envelope
end

#imageGoogle::Apis::OndemandscanningV1beta1::ImageOccurrence

Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM . Corresponds to the JSON property image



2492
2493
2494
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2492

def image
  @image
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


2498
2499
2500
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2498

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


2504
2505
2506
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2504

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


2511
2512
2513
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2511

def note_name
  @note_name
end

#packageGoogle::Apis::OndemandscanningV1beta1::PackageOccurrence

Details on how a particular software package was installed on a system. Corresponds to the JSON property package



2516
2517
2518
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2516

def package
  @package
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


2521
2522
2523
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2521

def remediation
  @remediation
end

#resource_uriString

Required. Immutable. A URI that represents the resource for which the occurrence applies. For example, https://gcr.io/project/image@sha256:123abc for a Docker image. Corresponds to the JSON property resourceUri

Returns:

  • (String)


2528
2529
2530
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2528

def resource_uri
  @resource_uri
end

#sbom_referenceGoogle::Apis::OndemandscanningV1beta1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



2535
2536
2537
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2535

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::OndemandscanningV1beta1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



2540
2541
2542
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2540

def secret
  @secret
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2545
2546
2547
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2545

def update_time
  @update_time
end

#upgradeGoogle::Apis::OndemandscanningV1beta1::UpgradeOccurrence

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update. Corresponds to the JSON property upgrade



2554
2555
2556
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2554

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::OndemandscanningV1beta1::VulnerabilityOccurrence

An occurrence of a severity vulnerability on a resource. Corresponds to the JSON property vulnerability



2559
2560
2561
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2559

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2566

def update!(**args)
  @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @envelope = args[:envelope] if args.key?(:envelope)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @package = args[:package] if args.key?(:package)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end