Class: Google::Apis::OndemandscanningV1beta1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



2383
2384
2385
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attestationGoogle::Apis::OndemandscanningV1beta1::AttestationOccurrence

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for lookup (how to find this attestation if you already know the authority and artifact to be verified) and intent (for which authority this attestation was intended to sign. Corresponds to the JSON property attestation



2270
2271
2272
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2270

def attestation
  @attestation
end

#buildGoogle::Apis::OndemandscanningV1beta1::BuildOccurrence

Details of a build occurrence. Corresponds to the JSON property build



2275
2276
2277
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2275

def build
  @build
end

#complianceGoogle::Apis::OndemandscanningV1beta1::ComplianceOccurrence

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason. Corresponds to the JSON property compliance



2281
2282
2283
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2281

def compliance
  @compliance
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2286

def create_time
  @create_time
end

#deploymentGoogle::Apis::OndemandscanningV1beta1::DeploymentOccurrence

The period during which some deployable was active in a runtime. Corresponds to the JSON property deployment



2291
2292
2293
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2291

def deployment
  @deployment
end

#discoveryGoogle::Apis::OndemandscanningV1beta1::DiscoveryOccurrence

Provides information about the analysis status of a discovered resource. Corresponds to the JSON property discovery



2296
2297
2298
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2296

def discovery
  @discovery
end

#dsse_attestationGoogle::Apis::OndemandscanningV1beta1::DsseAttestationOccurrence

Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at the top level of the Occurrence. Corresponds to the JSON property dsseAttestation



2302
2303
2304
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2302

def dsse_attestation
  @dsse_attestation
end

#envelopeGoogle::Apis::OndemandscanningV1beta1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



2308
2309
2310
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2308

def envelope
  @envelope
end

#imageGoogle::Apis::OndemandscanningV1beta1::ImageOccurrence

Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM . Corresponds to the JSON property image



2314
2315
2316
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2314

def image
  @image
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


2320
2321
2322
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2320

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


2326
2327
2328
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2326

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


2333
2334
2335
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2333

def note_name
  @note_name
end

#packageGoogle::Apis::OndemandscanningV1beta1::PackageOccurrence

Details on how a particular software package was installed on a system. Corresponds to the JSON property package



2338
2339
2340
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2338

def package
  @package
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


2343
2344
2345
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2343

def remediation
  @remediation
end

#resource_uriString

Required. Immutable. A URI that represents the resource for which the occurrence applies. For example, https://gcr.io/project/image@sha256:123abc for a Docker image. Corresponds to the JSON property resourceUri

Returns:

  • (String)


2350
2351
2352
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2350

def resource_uri
  @resource_uri
end

#sbom_referenceGoogle::Apis::OndemandscanningV1beta1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



2357
2358
2359
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2357

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::OndemandscanningV1beta1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



2362
2363
2364
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2362

def secret
  @secret
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2367
2368
2369
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2367

def update_time
  @update_time
end

#upgradeGoogle::Apis::OndemandscanningV1beta1::UpgradeOccurrence

An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update. Corresponds to the JSON property upgrade



2376
2377
2378
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2376

def upgrade
  @upgrade
end

#vulnerabilityGoogle::Apis::OndemandscanningV1beta1::VulnerabilityOccurrence

An occurrence of a severity vulnerability on a resource. Corresponds to the JSON property vulnerability



2381
2382
2383
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2381

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2388

def update!(**args)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @compliance = args[:compliance] if args.key?(:compliance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @discovery = args[:discovery] if args.key?(:discovery)
  @dsse_attestation = args[:dsse_attestation] if args.key?(:dsse_attestation)
  @envelope = args[:envelope] if args.key?(:envelope)
  @image = args[:image] if args.key?(:image)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @package = args[:package] if args.key?(:package)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade = args[:upgrade] if args.key?(:upgrade)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end