Class: Google::Apis::OndemandscanningV1beta1::PackageData
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::PackageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the package.
-
#binary_source_info ⇒ Array<Google::Apis::OndemandscanningV1beta1::BinarySourceInfo>
A bundle containing the binary and source information.
-
#binary_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
DEPRECATED Corresponds to the JSON property
binaryVersion. -
#cpe_uri ⇒ String
The cpe_uri in cpe format in which the vulnerability may manifest.
-
#dependency_chain ⇒ Array<Google::Apis::OndemandscanningV1beta1::LanguagePackageDependency>
The dependency chain between this package and the user's artifact.
-
#file_location ⇒ Array<Google::Apis::OndemandscanningV1beta1::FileLocation>
The path to the jar file / go binary file.
-
#hash_digest ⇒ String
HashDigest stores the SHA512 hash digest of the jar file if the package is of type Maven.
-
#ingestion_sources ⇒ Array<Google::Apis::OndemandscanningV1beta1::IngestionSource>
The list of sources that were scanned to find this package.
-
#layer_details ⇒ Google::Apis::OndemandscanningV1beta1::LayerDetails
Details about the layer a package was found in.
-
#licenses ⇒ Array<String>
The list of licenses found that are related to a given package.
-
#maintainer ⇒ Google::Apis::OndemandscanningV1beta1::Maintainer
The maintainer of the package.
-
#os ⇒ String
The OS affected by a vulnerability Used to generate the cpe_uri for OS packages Corresponds to the JSON property
os. -
#os_version ⇒ String
The version of the OS Used to generate the cpe_uri for OS packages Corresponds to the JSON property
osVersion. -
#package ⇒ String
The package being analysed for vulnerabilities Corresponds to the JSON property
package. -
#package_type ⇒ String
The type of package: os, maven, go, etc.
-
#patched_cve ⇒ Array<String>
CVEs that this package is no longer vulnerable to Corresponds to the JSON property
patchedCve. -
#source_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
DEPRECATED Corresponds to the JSON property
sourceVersion. -
#unused ⇒ String
Corresponds to the JSON property
unused. -
#version ⇒ String
The version of the package being analysed Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageData
constructor
A new instance of PackageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageData
Returns a new instance of PackageData.
2807 2808 2809 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The architecture of the package.
Corresponds to the JSON property architecture
2704 2705 2706 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2704 def architecture @architecture end |
#binary_source_info ⇒ Array<Google::Apis::OndemandscanningV1beta1::BinarySourceInfo>
A bundle containing the binary and source information.
Corresponds to the JSON property binarySourceInfo
2709 2710 2711 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2709 def binary_source_info @binary_source_info end |
#binary_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
DEPRECATED
Corresponds to the JSON property binaryVersion
2714 2715 2716 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2714 def binary_version @binary_version end |
#cpe_uri ⇒ String
The cpe_uri in cpe format in which
the vulnerability may manifest. Examples include distro or storage location
for vulnerable jar.
Corresponds to the JSON property cpeUri
2721 2722 2723 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2721 def cpe_uri @cpe_uri end |
#dependency_chain ⇒ Array<Google::Apis::OndemandscanningV1beta1::LanguagePackageDependency>
The dependency chain between this package and the user's artifact. List in
order from the customer's package under review first, to the current package
last. Inclusive of the original package and the current package.
Corresponds to the JSON property dependencyChain
2728 2729 2730 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2728 def dependency_chain @dependency_chain end |
#file_location ⇒ Array<Google::Apis::OndemandscanningV1beta1::FileLocation>
The path to the jar file / go binary file.
Corresponds to the JSON property fileLocation
2733 2734 2735 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2733 def file_location @file_location end |
#hash_digest ⇒ String
HashDigest stores the SHA512 hash digest of the jar file if the package is of
type Maven. This field will be unset for non Maven packages.
Corresponds to the JSON property hashDigest
2739 2740 2741 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2739 def hash_digest @hash_digest end |
#ingestion_sources ⇒ Array<Google::Apis::OndemandscanningV1beta1::IngestionSource>
The list of sources that were scanned to find this package. This can be a
Docker image, an SBOM attachment, or both, for example.
Corresponds to the JSON property ingestionSources
2745 2746 2747 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2745 def ingestion_sources @ingestion_sources end |
#layer_details ⇒ Google::Apis::OndemandscanningV1beta1::LayerDetails
Details about the layer a package was found in.
Corresponds to the JSON property layerDetails
2750 2751 2752 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2750 def layer_details @layer_details end |
#licenses ⇒ Array<String>
The list of licenses found that are related to a given package. Note that
licenses may also be stored on the BinarySourceInfo. If there is no
BinarySourceInfo (because there's no concept of source vs binary), then it
will be stored here, while if there are BinarySourceInfos, it will be stored
there, as one source can have multiple binaries with different licenses.
Corresponds to the JSON property licenses
2759 2760 2761 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2759 def licenses @licenses end |
#maintainer ⇒ Google::Apis::OndemandscanningV1beta1::Maintainer
The maintainer of the package.
Corresponds to the JSON property maintainer
2764 2765 2766 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2764 def maintainer @maintainer end |
#os ⇒ String
The OS affected by a vulnerability Used to generate the cpe_uri for OS
packages
Corresponds to the JSON property os
2770 2771 2772 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2770 def os @os end |
#os_version ⇒ String
The version of the OS Used to generate the cpe_uri for OS packages
Corresponds to the JSON property osVersion
2775 2776 2777 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2775 def os_version @os_version end |
#package ⇒ String
The package being analysed for vulnerabilities
Corresponds to the JSON property package
2780 2781 2782 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2780 def package @package end |
#package_type ⇒ String
The type of package: os, maven, go, etc.
Corresponds to the JSON property packageType
2785 2786 2787 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2785 def package_type @package_type end |
#patched_cve ⇒ Array<String>
CVEs that this package is no longer vulnerable to
Corresponds to the JSON property patchedCve
2790 2791 2792 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2790 def patched_cve @patched_cve end |
#source_version ⇒ Google::Apis::OndemandscanningV1beta1::PackageVersion
DEPRECATED
Corresponds to the JSON property sourceVersion
2795 2796 2797 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2795 def source_version @source_version end |
#unused ⇒ String
Corresponds to the JSON property unused
2800 2801 2802 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2800 def unused @unused end |
#version ⇒ String
The version of the package being analysed
Corresponds to the JSON property version
2805 2806 2807 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2805 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2812 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @binary_source_info = args[:binary_source_info] if args.key?(:binary_source_info) @binary_version = args[:binary_version] if args.key?(:binary_version) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @dependency_chain = args[:dependency_chain] if args.key?(:dependency_chain) @file_location = args[:file_location] if args.key?(:file_location) @hash_digest = args[:hash_digest] if args.key?(:hash_digest) @ingestion_sources = args[:ingestion_sources] if args.key?(:ingestion_sources) @layer_details = args[:layer_details] if args.key?(:layer_details) @licenses = args[:licenses] if args.key?(:licenses) @maintainer = args[:maintainer] if args.key?(:maintainer) @os = args[:os] if args.key?(:os) @os_version = args[:os_version] if args.key?(:os_version) @package = args[:package] if args.key?(:package) @package_type = args[:package_type] if args.key?(:package_type) @patched_cve = args[:patched_cve] if args.key?(:patched_cve) @source_version = args[:source_version] if args.key?(:source_version) @unused = args[:unused] if args.key?(:unused) @version = args[:version] if args.key?(:version) end |