Class: Google::Apis::OndemandscanningV1beta1::PackageData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageData

Returns a new instance of PackageData.



2696
2697
2698
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the package. Corresponds to the JSON property architecture

Returns:

  • (String)


2599
2600
2601
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2599

def architecture
  @architecture
end

#binary_source_infoArray<Google::Apis::OndemandscanningV1beta1::BinarySourceInfo>

A bundle containing the binary and source information. Corresponds to the JSON property binarySourceInfo



2604
2605
2606
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2604

def binary_source_info
  @binary_source_info
end

#binary_versionGoogle::Apis::OndemandscanningV1beta1::PackageVersion

DEPRECATED Corresponds to the JSON property binaryVersion



2609
2610
2611
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2609

def binary_version
  @binary_version
end

#cpe_uriString

The cpe_uri in cpe format in which the vulnerability may manifest. Examples include distro or storage location for vulnerable jar. Corresponds to the JSON property cpeUri

Returns:

  • (String)


2616
2617
2618
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2616

def cpe_uri
  @cpe_uri
end

#dependency_chainArray<Google::Apis::OndemandscanningV1beta1::LanguagePackageDependency>

The dependency chain between this package and the user's artifact. List in order from the customer's package under review first, to the current package last. Inclusive of the original package and the current package. Corresponds to the JSON property dependencyChain



2623
2624
2625
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2623

def dependency_chain
  @dependency_chain
end

#file_locationArray<Google::Apis::OndemandscanningV1beta1::FileLocation>

The path to the jar file / go binary file. Corresponds to the JSON property fileLocation



2628
2629
2630
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2628

def file_location
  @file_location
end

#hash_digestString

HashDigest stores the SHA512 hash digest of the jar file if the package is of type Maven. This field will be unset for non Maven packages. Corresponds to the JSON property hashDigest

Returns:

  • (String)


2634
2635
2636
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2634

def hash_digest
  @hash_digest
end

#layer_detailsGoogle::Apis::OndemandscanningV1beta1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



2639
2640
2641
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2639

def layer_details
  @layer_details
end

#licensesArray<String>

The list of licenses found that are related to a given package. Note that licenses may also be stored on the BinarySourceInfo. If there is no BinarySourceInfo (because there's no concept of source vs binary), then it will be stored here, while if there are BinarySourceInfos, it will be stored there, as one source can have multiple binaries with different licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2648
2649
2650
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2648

def licenses
  @licenses
end

#maintainerGoogle::Apis::OndemandscanningV1beta1::Maintainer

The maintainer of the package. Corresponds to the JSON property maintainer



2653
2654
2655
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2653

def maintainer
  @maintainer
end

#osString

The OS affected by a vulnerability Used to generate the cpe_uri for OS packages Corresponds to the JSON property os

Returns:

  • (String)


2659
2660
2661
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2659

def os
  @os
end

#os_versionString

The version of the OS Used to generate the cpe_uri for OS packages Corresponds to the JSON property osVersion

Returns:

  • (String)


2664
2665
2666
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2664

def os_version
  @os_version
end

#packageString

The package being analysed for vulnerabilities Corresponds to the JSON property package

Returns:

  • (String)


2669
2670
2671
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2669

def package
  @package
end

#package_typeString

The type of package: os, maven, go, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


2674
2675
2676
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2674

def package_type
  @package_type
end

#patched_cveArray<String>

CVEs that this package is no longer vulnerable to Corresponds to the JSON property patchedCve

Returns:

  • (Array<String>)


2679
2680
2681
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2679

def patched_cve
  @patched_cve
end

#source_versionGoogle::Apis::OndemandscanningV1beta1::PackageVersion

DEPRECATED Corresponds to the JSON property sourceVersion



2684
2685
2686
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2684

def source_version
  @source_version
end

#unusedString

Corresponds to the JSON property unused

Returns:

  • (String)


2689
2690
2691
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2689

def unused
  @unused
end

#versionString

The version of the package being analysed Corresponds to the JSON property version

Returns:

  • (String)


2694
2695
2696
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2694

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
2718
2719
2720
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2701

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @binary_source_info = args[:binary_source_info] if args.key?(:binary_source_info)
  @binary_version = args[:binary_version] if args.key?(:binary_version)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @dependency_chain = args[:dependency_chain] if args.key?(:dependency_chain)
  @file_location = args[:file_location] if args.key?(:file_location)
  @hash_digest = args[:hash_digest] if args.key?(:hash_digest)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @licenses = args[:licenses] if args.key?(:licenses)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @os = args[:os] if args.key?(:os)
  @os_version = args[:os_version] if args.key?(:os_version)
  @package = args[:package] if args.key?(:package)
  @package_type = args[:package_type] if args.key?(:package_type)
  @patched_cve = args[:patched_cve] if args.key?(:patched_cve)
  @source_version = args[:source_version] if args.key?(:source_version)
  @unused = args[:unused] if args.key?(:unused)
  @version = args[:version] if args.key?(:version)
end