Class: Google::Apis::OndemandscanningV1beta1::PackageData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageData

Returns a new instance of PackageData.



2578
2579
2580
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the package. Corresponds to the JSON property architecture

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2481

def architecture
  @architecture
end

#binary_source_infoArray<Google::Apis::OndemandscanningV1beta1::BinarySourceInfo>

A bundle containing the binary and source information. Corresponds to the JSON property binarySourceInfo



2486
2487
2488
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2486

def binary_source_info
  @binary_source_info
end

#binary_versionGoogle::Apis::OndemandscanningV1beta1::PackageVersion

DEPRECATED Corresponds to the JSON property binaryVersion



2491
2492
2493
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2491

def binary_version
  @binary_version
end

#cpe_uriString

The cpe_uri in cpe format in which the vulnerability may manifest. Examples include distro or storage location for vulnerable jar. Corresponds to the JSON property cpeUri

Returns:

  • (String)


2498
2499
2500
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2498

def cpe_uri
  @cpe_uri
end

#dependency_chainArray<Google::Apis::OndemandscanningV1beta1::LanguagePackageDependency>

The dependency chain between this package and the user's artifact. List in order from the customer's package under review first, to the current package last. Inclusive of the original package and the current package. Corresponds to the JSON property dependencyChain



2505
2506
2507
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2505

def dependency_chain
  @dependency_chain
end

#file_locationArray<Google::Apis::OndemandscanningV1beta1::FileLocation>

The path to the jar file / go binary file. Corresponds to the JSON property fileLocation



2510
2511
2512
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2510

def file_location
  @file_location
end

#hash_digestString

HashDigest stores the SHA512 hash digest of the jar file if the package is of type Maven. This field will be unset for non Maven packages. Corresponds to the JSON property hashDigest

Returns:

  • (String)


2516
2517
2518
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2516

def hash_digest
  @hash_digest
end

#layer_detailsGoogle::Apis::OndemandscanningV1beta1::LayerDetails

Details about the layer a package was found in. Corresponds to the JSON property layerDetails



2521
2522
2523
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2521

def layer_details
  @layer_details
end

#licensesArray<String>

The list of licenses found that are related to a given package. Note that licenses may also be stored on the BinarySourceInfo. If there is no BinarySourceInfo (because there's no concept of source vs binary), then it will be stored here, while if there are BinarySourceInfos, it will be stored there, as one source can have multiple binaries with different licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2530
2531
2532
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2530

def licenses
  @licenses
end

#maintainerGoogle::Apis::OndemandscanningV1beta1::Maintainer

The maintainer of the package. Corresponds to the JSON property maintainer



2535
2536
2537
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2535

def maintainer
  @maintainer
end

#osString

The OS affected by a vulnerability Used to generate the cpe_uri for OS packages Corresponds to the JSON property os

Returns:

  • (String)


2541
2542
2543
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2541

def os
  @os
end

#os_versionString

The version of the OS Used to generate the cpe_uri for OS packages Corresponds to the JSON property osVersion

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2546

def os_version
  @os_version
end

#packageString

The package being analysed for vulnerabilities Corresponds to the JSON property package

Returns:

  • (String)


2551
2552
2553
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2551

def package
  @package
end

#package_typeString

The type of package: os, maven, go, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2556

def package_type
  @package_type
end

#patched_cveArray<String>

CVEs that this package is no longer vulnerable to Corresponds to the JSON property patchedCve

Returns:

  • (Array<String>)


2561
2562
2563
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2561

def patched_cve
  @patched_cve
end

#source_versionGoogle::Apis::OndemandscanningV1beta1::PackageVersion

DEPRECATED Corresponds to the JSON property sourceVersion



2566
2567
2568
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2566

def source_version
  @source_version
end

#unusedString

Corresponds to the JSON property unused

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2571

def unused
  @unused
end

#versionString

The version of the package being analysed Corresponds to the JSON property version

Returns:

  • (String)


2576
2577
2578
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2576

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2583

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @binary_source_info = args[:binary_source_info] if args.key?(:binary_source_info)
  @binary_version = args[:binary_version] if args.key?(:binary_version)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @dependency_chain = args[:dependency_chain] if args.key?(:dependency_chain)
  @file_location = args[:file_location] if args.key?(:file_location)
  @hash_digest = args[:hash_digest] if args.key?(:hash_digest)
  @layer_details = args[:layer_details] if args.key?(:layer_details)
  @licenses = args[:licenses] if args.key?(:licenses)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @os = args[:os] if args.key?(:os)
  @os_version = args[:os_version] if args.key?(:os_version)
  @package = args[:package] if args.key?(:package)
  @package_type = args[:package_type] if args.key?(:package_type)
  @patched_cve = args[:patched_cve] if args.key?(:patched_cve)
  @source_version = args[:source_version] if args.key?(:source_version)
  @unused = args[:unused] if args.key?(:unused)
  @version = args[:version] if args.key?(:version)
end