Class: Google::Apis::OndemandscanningV1beta1::PackageIssue
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::PackageIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_cpe_uri ⇒ String
Required.
-
#affected_package ⇒ String
Required.
-
#affected_version ⇒ Google::Apis::OndemandscanningV1beta1::Version
Version contains structured information about the version of a package.
-
#effective_severity ⇒ String
Output only.
-
#file_location ⇒ Array<Google::Apis::OndemandscanningV1beta1::GrafeasV1FileLocation>
The location at which this package was found.
-
#fix_available ⇒ Boolean
(also: #fix_available?)
Output only.
-
#fixed_cpe_uri ⇒ String
The CPE URI this vulnerability was fixed in.
-
#fixed_package ⇒ String
The package this vulnerability was fixed in.
-
#fixed_version ⇒ Google::Apis::OndemandscanningV1beta1::Version
Version contains structured information about the version of a package.
-
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageIssue
constructor
A new instance of PackageIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageIssue
Returns a new instance of PackageIssue.
2896 2897 2898 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_cpe_uri ⇒ String
Required. The CPE URI this
vulnerability was found in.
Corresponds to the JSON property affectedCpeUri
2844 2845 2846 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2844 def affected_cpe_uri @affected_cpe_uri end |
#affected_package ⇒ String
Required. The package this vulnerability was found in.
Corresponds to the JSON property affectedPackage
2849 2850 2851 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2849 def affected_package @affected_package end |
#affected_version ⇒ Google::Apis::OndemandscanningV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property affectedVersion
2854 2855 2856 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2854 def affected_version @affected_version end |
#effective_severity ⇒ String
Output only. The distro or language system assigned severity for this
vulnerability when that is available and note provider assigned severity when
it is not available.
Corresponds to the JSON property effectiveSeverity
2861 2862 2863 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2861 def effective_severity @effective_severity end |
#file_location ⇒ Array<Google::Apis::OndemandscanningV1beta1::GrafeasV1FileLocation>
The location at which this package was found.
Corresponds to the JSON property fileLocation
2866 2867 2868 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2866 def file_location @file_location end |
#fix_available ⇒ Boolean Also known as: fix_available?
Output only. Whether a fix is available for this package.
Corresponds to the JSON property fixAvailable
2871 2872 2873 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2871 def fix_available @fix_available end |
#fixed_cpe_uri ⇒ String
The CPE URI this vulnerability was
fixed in. It is possible for this to be different from the affected_cpe_uri.
Corresponds to the JSON property fixedCpeUri
2878 2879 2880 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2878 def fixed_cpe_uri @fixed_cpe_uri end |
#fixed_package ⇒ String
The package this vulnerability was fixed in. It is possible for this to be
different from the affected_package.
Corresponds to the JSON property fixedPackage
2884 2885 2886 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2884 def fixed_package @fixed_package end |
#fixed_version ⇒ Google::Apis::OndemandscanningV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property fixedVersion
2889 2890 2891 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2889 def fixed_version @fixed_version end |
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Corresponds to the JSON property packageType
2894 2895 2896 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2894 def package_type @package_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2901 def update!(**args) @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri) @affected_package = args[:affected_package] if args.key?(:affected_package) @affected_version = args[:affected_version] if args.key?(:affected_version) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @file_location = args[:file_location] if args.key?(:file_location) @fix_available = args[:fix_available] if args.key?(:fix_available) @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri) @fixed_package = args[:fixed_package] if args.key?(:fixed_package) @fixed_version = args[:fixed_version] if args.key?(:fixed_version) @package_type = args[:package_type] if args.key?(:package_type) end |