Class: Google::Apis::OndemandscanningV1beta1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



2666
2667
2668
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_cpe_uriString

Required. The CPE URI this vulnerability was found in. Corresponds to the JSON property affectedCpeUri

Returns:

  • (String)


2614
2615
2616
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2614

def affected_cpe_uri
  @affected_cpe_uri
end

#affected_packageString

Required. The package this vulnerability was found in. Corresponds to the JSON property affectedPackage

Returns:

  • (String)


2619
2620
2621
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2619

def affected_package
  @affected_package
end

#affected_versionGoogle::Apis::OndemandscanningV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property affectedVersion



2624
2625
2626
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2624

def affected_version
  @affected_version
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


2631
2632
2633
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2631

def effective_severity
  @effective_severity
end

#file_locationArray<Google::Apis::OndemandscanningV1beta1::GrafeasV1FileLocation>

The location at which this package was found. Corresponds to the JSON property fileLocation



2636
2637
2638
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2636

def file_location
  @file_location
end

#fix_availableBoolean Also known as: fix_available?

Output only. Whether a fix is available for this package. Corresponds to the JSON property fixAvailable

Returns:

  • (Boolean)


2641
2642
2643
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2641

def fix_available
  @fix_available
end

#fixed_cpe_uriString

The CPE URI this vulnerability was fixed in. It is possible for this to be different from the affected_cpe_uri. Corresponds to the JSON property fixedCpeUri

Returns:

  • (String)


2648
2649
2650
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2648

def fixed_cpe_uri
  @fixed_cpe_uri
end

#fixed_packageString

The package this vulnerability was fixed in. It is possible for this to be different from the affected_package. Corresponds to the JSON property fixedPackage

Returns:

  • (String)


2654
2655
2656
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2654

def fixed_package
  @fixed_package
end

#fixed_versionGoogle::Apis::OndemandscanningV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property fixedVersion



2659
2660
2661
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2659

def fixed_version
  @fixed_version
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


2664
2665
2666
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2664

def package_type
  @package_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2671

def update!(**args)
  @affected_cpe_uri = args[:affected_cpe_uri] if args.key?(:affected_cpe_uri)
  @affected_package = args[:affected_package] if args.key?(:affected_package)
  @affected_version = args[:affected_version] if args.key?(:affected_version)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @file_location = args[:file_location] if args.key?(:file_location)
  @fix_available = args[:fix_available] if args.key?(:fix_available)
  @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri)
  @fixed_package = args[:fixed_package] if args.key?(:fixed_package)
  @fixed_version = args[:fixed_version] if args.key?(:fixed_version)
  @package_type = args[:package_type] if args.key?(:package_type)
end