Class: Google::Apis::OndemandscanningV1beta1::PackageOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::PackageOccurrence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Details on how a particular software package was installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::OndemandscanningV1beta1::License
License information.
-
#location ⇒ Array<Google::Apis::OndemandscanningV1beta1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::OndemandscanningV1beta1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageOccurrence
constructor
A new instance of PackageOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageOccurrence
Returns a new instance of PackageOccurrence.
2959 2960 2961 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
2923 2924 2925 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2923 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
2930 2931 2932 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2930 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::OndemandscanningV1beta1::License
License information.
Corresponds to the JSON property license
2935 2936 2937 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2935 def license @license end |
#location ⇒ Array<Google::Apis::OndemandscanningV1beta1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
2941 2942 2943 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2941 def location @location end |
#name ⇒ String
Required. Output only. The name of the installed package.
Corresponds to the JSON property name
2946 2947 2948 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2946 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
2952 2953 2954 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2952 def package_type @package_type end |
#version ⇒ Google::Apis::OndemandscanningV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
2957 2958 2959 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2957 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2964 2965 2966 2967 2968 2969 2970 2971 2972 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2964 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |