Class: Google::Apis::OndemandscanningV1beta1::PackageVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageVersion

Returns a new instance of PackageVersion.



2767
2768
2769
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licensesArray<String>

The licenses associated with this package. Note that this has to go on the PackageVersion level, because we can have cases with images with the same source having different licences. E.g. in Alpine, musl and musl-utils both have the same origin musl, but have different sets of licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2755
2756
2757
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2755

def licenses
  @licenses
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


2760
2761
2762
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2760

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


2765
2766
2767
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2765

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2772
2773
2774
2775
2776
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2772

def update!(**args)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end