Class: Google::Apis::OndemandscanningV1beta1::Recipe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Recipe

Returns a new instance of Recipe.



3001
3002
3003
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsArray<Hash<String,Object>>

Collection of all external inputs that influenced the build on top of recipe. definedInMaterial and recipe.entryPoint. For example, if the recipe type were " make", then this might be the flags passed to make aside from the target, which is captured in recipe.entryPoint. Since the arguments field can greatly vary in structure, depending on the builder and recipe type, this is of form " Any". Corresponds to the JSON property arguments

Returns:

  • (Array<Hash<String,Object>>)


2967
2968
2969
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2967

def arguments
  @arguments
end

#defined_in_materialFixnum

Index in materials containing the recipe steps that are not implied by recipe. type. For example, if the recipe type were "make", then this would point to the source containing the Makefile, not the make program itself. Set to -1 if the recipe doesn't come from a material, as zero is default unset value for int64. Corresponds to the JSON property definedInMaterial

Returns:

  • (Fixnum)


2976
2977
2978
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2976

def defined_in_material
  @defined_in_material
end

#entry_pointString

String identifying the entry point into the build. This is often a path to a configuration file and/or a target label within that file. The syntax and meaning are defined by recipe.type. For example, if the recipe type were "make" , then this would reference the directory in which to run make as well as which target to use. Corresponds to the JSON property entryPoint

Returns:

  • (String)


2985
2986
2987
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2985

def entry_point
  @entry_point
end

#environmentArray<Hash<String,Object>>

Any other builder-controlled inputs necessary for correctly evaluating the recipe. Usually only needed for reproducing the build but not evaluated as part of policy. Since the environment field can greatly vary in structure, depending on the builder and recipe type, this is of form "Any". Corresponds to the JSON property environment

Returns:

  • (Array<Hash<String,Object>>)


2993
2994
2995
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2993

def environment
  @environment
end

#typeString

URI indicating what type of recipe was performed. It determines the meaning of recipe.entryPoint, recipe.arguments, recipe.environment, and materials. Corresponds to the JSON property type

Returns:

  • (String)


2999
3000
3001
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 2999

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3006
3007
3008
3009
3010
3011
3012
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3006

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @defined_in_material = args[:defined_in_material] if args.key?(:defined_in_material)
  @entry_point = args[:entry_point] if args.key?(:entry_point)
  @environment = args[:environment] if args.key?(:environment)
  @type = args[:type] if args.key?(:type)
end