Class: Google::Apis::OndemandscanningV1beta1::Risk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Risk

Returns a new instance of Risk.



3169
3170
3171
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cisa_kevGoogle::Apis::OndemandscanningV1beta1::CisaKnownExploitedVulnerabilities

CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild. Corresponds to the JSON property cisaKev



3161
3162
3163
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3161

def cisa_kev
  @cisa_kev
end

#epssGoogle::Apis::OndemandscanningV1beta1::ExploitPredictionScoringSystem

The Exploit Prediction Scoring System (EPSS) estimates the likelihood ( probability) that a software vulnerability will be exploited in the wild. Corresponds to the JSON property epss



3167
3168
3169
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3167

def epss
  @epss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3174
3175
3176
3177
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3174

def update!(**args)
  @cisa_kev = args[:cisa_kev] if args.key?(:cisa_kev)
  @epss = args[:epss] if args.key?(:epss)
end