Class: Google::Apis::OndemandscanningV1beta1::SlsaProvenance
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::SlsaProvenance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#builder ⇒ Google::Apis::OndemandscanningV1beta1::SlsaBuilder
required Corresponds to the JSON property
builder. -
#materials ⇒ Array<Google::Apis::OndemandscanningV1beta1::Material>
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
-
#metadata ⇒ Google::Apis::OndemandscanningV1beta1::SlsaMetadata
Other properties of the build.
-
#recipe ⇒ Google::Apis::OndemandscanningV1beta1::SlsaRecipe
Steps taken to build the artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenance
constructor
A new instance of SlsaProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenance
Returns a new instance of SlsaProvenance.
3730 3731 3732 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builder ⇒ Google::Apis::OndemandscanningV1beta1::SlsaBuilder
required
Corresponds to the JSON property builder
3709 3710 3711 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3709 def builder @builder end |
#materials ⇒ Array<Google::Apis::OndemandscanningV1beta1::Material>
The collection of artifacts that influenced the build including sources,
dependencies, build tools, base images, and so on. This is considered to be
incomplete unless metadata.completeness.materials is true. Unset or null is
equivalent to empty.
Corresponds to the JSON property materials
3717 3718 3719 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3717 def materials @materials end |
#metadata ⇒ Google::Apis::OndemandscanningV1beta1::SlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
3722 3723 3724 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3722 def @metadata end |
#recipe ⇒ Google::Apis::OndemandscanningV1beta1::SlsaRecipe
Steps taken to build the artifact. For a TaskRun, typically each container
corresponds to one step in the recipe.
Corresponds to the JSON property recipe
3728 3729 3730 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3728 def recipe @recipe end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3735 3736 3737 3738 3739 3740 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3735 def update!(**args) @builder = args[:builder] if args.key?(:builder) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) @recipe = args[:recipe] if args.key?(:recipe) end |