Class: Google::Apis::OndemandscanningV1beta1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



3686
3687
3688
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::OndemandscanningV1beta1::SlsaBuilder

required Corresponds to the JSON property builder



3665
3666
3667
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3665

def builder
  @builder
end

#materialsArray<Google::Apis::OndemandscanningV1beta1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



3673
3674
3675
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3673

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1beta1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



3678
3679
3680
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3678

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1beta1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



3684
3685
3686
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3684

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3691
3692
3693
3694
3695
3696
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3691

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end