Class: Google::Apis::OndemandscanningV1beta1::SlsaProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenance

Returns a new instance of SlsaProvenance.



3618
3619
3620
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#builderGoogle::Apis::OndemandscanningV1beta1::SlsaBuilder

required Corresponds to the JSON property builder



3597
3598
3599
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3597

def builder
  @builder
end

#materialsArray<Google::Apis::OndemandscanningV1beta1::Material>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty. Corresponds to the JSON property materials



3605
3606
3607
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3605

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1beta1::SlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



3610
3611
3612
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3610

def 
  @metadata
end

#recipeGoogle::Apis::OndemandscanningV1beta1::SlsaRecipe

Steps taken to build the artifact. For a TaskRun, typically each container corresponds to one step in the recipe. Corresponds to the JSON property recipe



3616
3617
3618
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3616

def recipe
  @recipe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3623
3624
3625
3626
3627
3628
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3623

def update!(**args)
  @builder = args[:builder] if args.key?(:builder)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
  @recipe = args[:recipe] if args.key?(:recipe)
end