Class: Google::Apis::OndemandscanningV1beta1::SlsaProvenanceZeroTwo
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::SlsaProvenanceZeroTwo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
See full explanation of fields at slsa.dev/provenance/v0.2.
Instance Attribute Summary collapse
-
#build_config ⇒ Hash<String,Object>
Corresponds to the JSON property
buildConfig. -
#build_type ⇒ String
Corresponds to the JSON property
buildType. -
#builder ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance.
-
#invocation ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
-
#materials ⇒ Array<Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>
Corresponds to the JSON property
materials. -
#metadata ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
constructor
A new instance of SlsaProvenanceZeroTwo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaProvenanceZeroTwo
Returns a new instance of SlsaProvenanceZeroTwo.
3755 3756 3757 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_config ⇒ Hash<String,Object>
Corresponds to the JSON property buildConfig
3727 3728 3729 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3727 def build_config @build_config end |
#build_type ⇒ String
Corresponds to the JSON property buildType
3732 3733 3734 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3732 def build_type @build_type end |
#builder ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder
Identifies the entity that executed the recipe, which is trusted to have
correctly performed the operation and populated this provenance.
Corresponds to the JSON property builder
3738 3739 3740 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3738 def builder @builder end |
#invocation ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation
Identifies the event that kicked off the build.
Corresponds to the JSON property invocation
3743 3744 3745 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3743 def invocation @invocation end |
#materials ⇒ Array<Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>
Corresponds to the JSON property materials
3748 3749 3750 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3748 def materials @materials end |
#metadata ⇒ Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata
Other properties of the build.
Corresponds to the JSON property metadata
3753 3754 3755 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3753 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3760 3761 3762 3763 3764 3765 3766 3767 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3760 def update!(**args) @build_config = args[:build_config] if args.key?(:build_config) @build_type = args[:build_type] if args.key?(:build_type) @builder = args[:builder] if args.key?(:builder) @invocation = args[:invocation] if args.key?(:invocation) @materials = args[:materials] if args.key?(:materials) @metadata = args[:metadata] if args.key?(:metadata) end |