Class: Google::Apis::OndemandscanningV1beta1::SlsaProvenanceZeroTwo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

See full explanation of fields at slsa.dev/provenance/v0.2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlsaProvenanceZeroTwo

Returns a new instance of SlsaProvenanceZeroTwo.



3575
3576
3577
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_configHash<String,Object>

Corresponds to the JSON property buildConfig

Returns:

  • (Hash<String,Object>)


3547
3548
3549
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3547

def build_config
  @build_config
end

#build_typeString

Corresponds to the JSON property buildType

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3552

def build_type
  @build_type
end

#builderGoogle::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaBuilder

Identifies the entity that executed the recipe, which is trusted to have correctly performed the operation and populated this provenance. Corresponds to the JSON property builder



3558
3559
3560
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3558

def builder
  @builder
end

#invocationGoogle::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaInvocation

Identifies the event that kicked off the build. Corresponds to the JSON property invocation



3563
3564
3565
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3563

def invocation
  @invocation
end

#materialsArray<Google::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial>

Corresponds to the JSON property materials



3568
3569
3570
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3568

def materials
  @materials
end

#metadataGoogle::Apis::OndemandscanningV1beta1::GrafeasV1SlsaProvenanceZeroTwoSlsaMetadata

Other properties of the build. Corresponds to the JSON property metadata



3573
3574
3575
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3573

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3580

def update!(**args)
  @build_config = args[:build_config] if args.key?(:build_config)
  @build_type = args[:build_type] if args.key?(:build_type)
  @builder = args[:builder] if args.key?(:builder)
  @invocation = args[:invocation] if args.key?(:invocation)
  @materials = args[:materials] if args.key?(:materials)
  @metadata = args[:metadata] if args.key?(:metadata)
end