Class: Google::Apis::OndemandscanningV1beta1::SourceContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceContext

Returns a new instance of SourceContext.



3901
3902
3903
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_repoGoogle::Apis::OndemandscanningV1beta1::CloudRepoSourceContext

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo. Corresponds to the JSON property cloudRepo



3883
3884
3885
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3883

def cloud_repo
  @cloud_repo
end

#gerritGoogle::Apis::OndemandscanningV1beta1::GerritSourceContext

A SourceContext referring to a Gerrit project. Corresponds to the JSON property gerrit



3888
3889
3890
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3888

def gerrit
  @gerrit
end

#gitGoogle::Apis::OndemandscanningV1beta1::GitSourceContext

A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub). Corresponds to the JSON property git



3894
3895
3896
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3894

def git
  @git
end

#labelsHash<String,String>

Labels with user defined metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3899
3900
3901
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3899

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3906
3907
3908
3909
3910
3911
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3906

def update!(**args)
  @cloud_repo = args[:cloud_repo] if args.key?(:cloud_repo)
  @gerrit = args[:gerrit] if args.key?(:gerrit)
  @git = args[:git] if args.key?(:git)
  @labels = args[:labels] if args.key?(:labels)
end