Class: Google::Apis::OndemandscanningV1beta1::UpgradeDistribution
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::UpgradeDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.
Instance Attribute Summary collapse
-
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed.
-
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to.
-
#cve ⇒ Array<String>
The cve tied to this Upgrade.
-
#severity ⇒ String
The severity as specified by the upstream operating system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeDistribution
constructor
A new instance of UpgradeDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeDistribution
Returns a new instance of UpgradeDistribution.
4009 4010 4011 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification ⇒ String
The operating system classification of this Upgrade, as specified by the
upstream operating system upgrade feed. For Windows the classification is one
of the category_ids listed at https://docs.microsoft.com/en-us/previous-
versions/windows/desktop/ff357803(v=vs.85)
Corresponds to the JSON property classification
3991 3992 3993 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3991 def classification @classification end |
#cpe_uri ⇒ String
Required - The specific operating system this metadata applies to. See https://
cpe.mitre.org/specification/.
Corresponds to the JSON property cpeUri
3997 3998 3999 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3997 def cpe_uri @cpe_uri end |
#cve ⇒ Array<String>
The cve tied to this Upgrade.
Corresponds to the JSON property cve
4002 4003 4004 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4002 def cve @cve end |
#severity ⇒ String
The severity as specified by the upstream operating system.
Corresponds to the JSON property severity
4007 4008 4009 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4007 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4014 4015 4016 4017 4018 4019 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4014 def update!(**args) @classification = args[:classification] if args.key?(:classification) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @cve = args[:cve] if args.key?(:cve) @severity = args[:severity] if args.key?(:severity) end |