Class: Google::Apis::OndemandscanningV1beta1::UpgradeDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeDistribution

Returns a new instance of UpgradeDistribution.



3947
3948
3949
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. For Windows the classification is one of the category_ids listed at https://docs.microsoft.com/en-us/previous- versions/windows/desktop/ff357803(v=vs.85) Corresponds to the JSON property classification

Returns:

  • (String)


3929
3930
3931
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3929

def classification
  @classification
end

#cpe_uriString

Required - The specific operating system this metadata applies to. See https:// cpe.mitre.org/specification/. Corresponds to the JSON property cpeUri

Returns:

  • (String)


3935
3936
3937
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3935

def cpe_uri
  @cpe_uri
end

#cveArray<String>

The cve tied to this Upgrade. Corresponds to the JSON property cve

Returns:

  • (Array<String>)


3940
3941
3942
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3940

def cve
  @cve
end

#severityString

The severity as specified by the upstream operating system. Corresponds to the JSON property severity

Returns:

  • (String)


3945
3946
3947
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3945

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3952
3953
3954
3955
3956
3957
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3952

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @cve = args[:cve] if args.key?(:cve)
  @severity = args[:severity] if args.key?(:severity)
end