Class: Google::Apis::OndemandscanningV1beta1::VexAssessment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

VexAssessment provides all publisher provided Vex information that is related to this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VexAssessment

Returns a new instance of VexAssessment.



4182
4183
4184
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs. Corresponds to the JSON property cve

Returns:

  • (String)


4140
4141
4142
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4140

def cve
  @cve
end

#impactsArray<String>

Contains information about the impact of this vulnerability, this will change with time. Corresponds to the JSON property impacts

Returns:

  • (Array<String>)


4146
4147
4148
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4146

def impacts
  @impacts
end

#justificationGoogle::Apis::OndemandscanningV1beta1::Justification

Justification provides the justification when the state of the assessment if NOT_AFFECTED. Corresponds to the JSON property justification



4152
4153
4154
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4152

def justification
  @justification
end

#note_nameString

The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID]. Corresponds to the JSON property noteName

Returns:

  • (String)


4158
4159
4160
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4158

def note_name
  @note_name
end

Holds a list of references associated with this vulnerability item and assessment. Corresponds to the JSON property relatedUris



4164
4165
4166
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4164

def related_uris
  @related_uris
end

#remediationsArray<Google::Apis::OndemandscanningV1beta1::Remediation>

Specifies details on how to handle (and presumably, fix) a vulnerability. Corresponds to the JSON property remediations



4169
4170
4171
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4169

def remediations
  @remediations
end

#stateString

Provides the state of this Vulnerability assessment. Corresponds to the JSON property state

Returns:

  • (String)


4174
4175
4176
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4174

def state
  @state
end

#vulnerability_idString

The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc. Corresponds to the JSON property vulnerabilityId

Returns:

  • (String)


4180
4181
4182
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4180

def vulnerability_id
  @vulnerability_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4187

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @impacts = args[:impacts] if args.key?(:impacts)
  @justification = args[:justification] if args.key?(:justification)
  @note_name = args[:note_name] if args.key?(:note_name)
  @related_uris = args[:related_uris] if args.key?(:related_uris)
  @remediations = args[:remediations] if args.key?(:remediations)
  @state = args[:state] if args.key?(:state)
  @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id)
end