Class: Google::Apis::OndemandscanningV1beta1::VexAssessment
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::VexAssessment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
VexAssessment provides all publisher provided Vex information that is related to this vulnerability.
Instance Attribute Summary collapse
-
#cve ⇒ String
Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability.
-
#impacts ⇒ Array<String>
Contains information about the impact of this vulnerability, this will change with time.
-
#justification ⇒ Google::Apis::OndemandscanningV1beta1::Justification
Justification provides the justification when the state of the assessment if NOT_AFFECTED.
-
#note_name ⇒ String
The VulnerabilityAssessment note from which this VexAssessment was generated.
-
#related_uris ⇒ Array<Google::Apis::OndemandscanningV1beta1::RelatedUrl>
Holds a list of references associated with this vulnerability item and assessment.
-
#remediations ⇒ Array<Google::Apis::OndemandscanningV1beta1::Remediation>
Specifies details on how to handle (and presumably, fix) a vulnerability.
-
#state ⇒ String
Provides the state of this Vulnerability assessment.
-
#vulnerability_id ⇒ String
The vulnerability identifier for this Assessment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VexAssessment
constructor
A new instance of VexAssessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VexAssessment
Returns a new instance of VexAssessment.
3996 3997 3998 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cve ⇒ String
Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking
number for the vulnerability. Deprecated: Use vulnerability_id instead to
denote CVEs.
Corresponds to the JSON property cve
3954 3955 3956 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3954 def cve @cve end |
#impacts ⇒ Array<String>
Contains information about the impact of this vulnerability, this will change
with time.
Corresponds to the JSON property impacts
3960 3961 3962 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3960 def impacts @impacts end |
#justification ⇒ Google::Apis::OndemandscanningV1beta1::Justification
Justification provides the justification when the state of the assessment if
NOT_AFFECTED.
Corresponds to the JSON property justification
3966 3967 3968 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3966 def justification @justification end |
#note_name ⇒ String
The VulnerabilityAssessment note from which this VexAssessment was generated.
This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID].
Corresponds to the JSON property noteName
3972 3973 3974 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3972 def note_name @note_name end |
#related_uris ⇒ Array<Google::Apis::OndemandscanningV1beta1::RelatedUrl>
Holds a list of references associated with this vulnerability item and
assessment.
Corresponds to the JSON property relatedUris
3978 3979 3980 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3978 def @related_uris end |
#remediations ⇒ Array<Google::Apis::OndemandscanningV1beta1::Remediation>
Specifies details on how to handle (and presumably, fix) a vulnerability.
Corresponds to the JSON property remediations
3983 3984 3985 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3983 def remediations @remediations end |
#state ⇒ String
Provides the state of this Vulnerability assessment.
Corresponds to the JSON property state
3988 3989 3990 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3988 def state @state end |
#vulnerability_id ⇒ String
The vulnerability identifier for this Assessment. Will hold one of common
identifiers e.g. CVE, GHSA etc.
Corresponds to the JSON property vulnerabilityId
3994 3995 3996 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 3994 def vulnerability_id @vulnerability_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4001 def update!(**args) @cve = args[:cve] if args.key?(:cve) @impacts = args[:impacts] if args.key?(:impacts) @justification = args[:justification] if args.key?(:justification) @note_name = args[:note_name] if args.key?(:note_name) @related_uris = args[:related_uris] if args.key?(:related_uris) @remediations = args[:remediations] if args.key?(:remediations) @state = args[:state] if args.key?(:state) @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id) end |