Class: Google::Apis::OndemandscanningV1beta1::WindowsUpdate
- Inherits:
-
Object
- Object
- Google::Apis::OndemandscanningV1beta1::WindowsUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb
Overview
Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate.
Instance Attribute Summary collapse
-
#categories ⇒ Array<Google::Apis::OndemandscanningV1beta1::Category>
The list of categories to which the update belongs.
-
#description ⇒ String
The localized description of the update.
-
#identity ⇒ Google::Apis::OndemandscanningV1beta1::Identity
The unique identifier of the update.
-
#kb_article_ids ⇒ Array<String>
The Microsoft Knowledge Base article IDs that are associated with the update.
-
#last_published_timestamp ⇒ String
The last published timestamp of the update.
-
#support_url ⇒ String
The hyperlink to the support information for the update.
-
#title ⇒ String
The localized title of the update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WindowsUpdate
constructor
A new instance of WindowsUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WindowsUpdate
Returns a new instance of WindowsUpdate.
4356 4357 4358 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categories ⇒ Array<Google::Apis::OndemandscanningV1beta1::Category>
The list of categories to which the update belongs.
Corresponds to the JSON property categories
4324 4325 4326 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4324 def categories @categories end |
#description ⇒ String
The localized description of the update.
Corresponds to the JSON property description
4329 4330 4331 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4329 def description @description end |
#identity ⇒ Google::Apis::OndemandscanningV1beta1::Identity
The unique identifier of the update.
Corresponds to the JSON property identity
4334 4335 4336 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4334 def identity @identity end |
#kb_article_ids ⇒ Array<String>
The Microsoft Knowledge Base article IDs that are associated with the update.
Corresponds to the JSON property kbArticleIds
4339 4340 4341 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4339 def kb_article_ids @kb_article_ids end |
#last_published_timestamp ⇒ String
The last published timestamp of the update.
Corresponds to the JSON property lastPublishedTimestamp
4344 4345 4346 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4344 def @last_published_timestamp end |
#support_url ⇒ String
The hyperlink to the support information for the update.
Corresponds to the JSON property supportUrl
4349 4350 4351 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4349 def support_url @support_url end |
#title ⇒ String
The localized title of the update.
Corresponds to the JSON property title
4354 4355 4356 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4354 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4361 4362 4363 4364 4365 4366 4367 4368 4369 |
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4361 def update!(**args) @categories = args[:categories] if args.key?(:categories) @description = args[:description] if args.key?(:description) @identity = args[:identity] if args.key?(:identity) @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids) @last_published_timestamp = args[:last_published_timestamp] if args.key?(:last_published_timestamp) @support_url = args[:support_url] if args.key?(:support_url) @title = args[:title] if args.key?(:title) end |