Class: Google::Apis::OndemandscanningV1beta1::WindowsUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ondemandscanning_v1beta1/classes.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb,
lib/google/apis/ondemandscanning_v1beta1/representations.rb

Overview

Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn- wuapi-iupdate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsUpdate

Returns a new instance of WindowsUpdate.



4176
4177
4178
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::OndemandscanningV1beta1::Category>

The list of categories to which the update belongs. Corresponds to the JSON property categories



4144
4145
4146
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4144

def categories
  @categories
end

#descriptionString

The localized description of the update. Corresponds to the JSON property description

Returns:

  • (String)


4149
4150
4151
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4149

def description
  @description
end

#identityGoogle::Apis::OndemandscanningV1beta1::Identity

The unique identifier of the update. Corresponds to the JSON property identity



4154
4155
4156
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4154

def identity
  @identity
end

#kb_article_idsArray<String>

The Microsoft Knowledge Base article IDs that are associated with the update. Corresponds to the JSON property kbArticleIds

Returns:

  • (Array<String>)


4159
4160
4161
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4159

def kb_article_ids
  @kb_article_ids
end

#last_published_timestampString

The last published timestamp of the update. Corresponds to the JSON property lastPublishedTimestamp

Returns:

  • (String)


4164
4165
4166
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4164

def last_published_timestamp
  @last_published_timestamp
end

#support_urlString

The hyperlink to the support information for the update. Corresponds to the JSON property supportUrl

Returns:

  • (String)


4169
4170
4171
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4169

def support_url
  @support_url
end

#titleString

The localized title of the update. Corresponds to the JSON property title

Returns:

  • (String)


4174
4175
4176
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4174

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4181
4182
4183
4184
4185
4186
4187
4188
4189
# File 'lib/google/apis/ondemandscanning_v1beta1/classes.rb', line 4181

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @identity = args[:identity] if args.key?(:identity)
  @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids)
  @last_published_timestamp = args[:last_published_timestamp] if args.key?(:last_published_timestamp)
  @support_url = args[:support_url] if args.key?(:support_url)
  @title = args[:title] if args.key?(:title)
end